@@ -66,7 +66,7 @@ class AssayResultCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_fields() -> Union[Fields, AssayFieldsCreate, UnknownType]:
@@ -75,7 +75,7 @@ class AssayResultCreate:
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    fields = Fields.from_dict(data)
+                    fields = Fields.from_dict(data, strict=True)
 
                     return fields
                 except:  # noqa: E722
@@ -83,7 +83,7 @@ class AssayResultCreate:
                 try:
                     if not isinstance(data, dict):
                         raise TypeError()
-                    fields = AssayFieldsCreate.from_dict(data)
+                    fields = AssayFieldsCreate.from_dict(data, strict=True)
 
                     return fields
                 except:  # noqa: E722
@@ -94,39 +94,61 @@ class AssayResultCreate:
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Fields, AssayFieldsCreate, UnknownType], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Fields, AssayFieldsCreate, UnknownType], UNSET)
 
         def get_schema_id() -> str:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(str, UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(str, UNSET)
 
         def get_field_validation() -> Union[Unset, AssayResultCreateFieldValidation]:
-            field_validation: Union[Unset, AssayResultCreateFieldValidation] = UNSET
+            field_validation: Union[Unset, Union[Unset, AssayResultCreateFieldValidation]] = UNSET
             _field_validation = d.pop("fieldValidation")
+
             if not isinstance(_field_validation, Unset):
                 field_validation = AssayResultCreateFieldValidation.from_dict(_field_validation)
 
             return field_validation
 
-        field_validation = (
-            get_field_validation()
-            if "fieldValidation" in d
-            else cast(Union[Unset, AssayResultCreateFieldValidation], UNSET)
-        )
+        try:
+            field_validation = get_field_validation()
+        except KeyError:
+            if strict:
+                raise
+            field_validation = cast(Union[Unset, AssayResultCreateFieldValidation], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_project_id() -> Union[Unset, None, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, None, str], UNSET)
 
         assay_result_create = cls(
             fields=fields,
