@@ -35,7 +35,7 @@ class AssayResultsCreateResponse:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_assay_results() -> Union[Unset, List[str]]:
@@ -43,7 +43,12 @@ class AssayResultsCreateResponse:
 
             return assay_results
 
-        assay_results = get_assay_results() if "assayResults" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            assay_results = get_assay_results()
+        except KeyError:
+            if strict:
+                raise
+            assay_results = cast(Union[Unset, List[str]], UNSET)
 
         assay_results_create_response = cls(
             assay_results=assay_results,
