@@ -42,32 +42,40 @@ class BatchUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_default_concentration() -> Union[Unset, DefaultConcentrationSummary]:
-            default_concentration: Union[Unset, DefaultConcentrationSummary] = UNSET
+            default_concentration: Union[Unset, Union[Unset, DefaultConcentrationSummary]] = UNSET
             _default_concentration = d.pop("defaultConcentration")
+
             if not isinstance(_default_concentration, Unset):
                 default_concentration = DefaultConcentrationSummary.from_dict(_default_concentration)
 
             return default_concentration
 
-        default_concentration = (
-            get_default_concentration()
-            if "defaultConcentration" in d
-            else cast(Union[Unset, DefaultConcentrationSummary], UNSET)
-        )
+        try:
+            default_concentration = get_default_concentration()
+        except KeyError:
+            if strict:
+                raise
+            default_concentration = cast(Union[Unset, DefaultConcentrationSummary], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         batch_update = cls(
             default_concentration=default_concentration,
