@@ -46,26 +46,36 @@ class BoxesPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_boxes() -> Union[Unset, List[Box]]:
             boxes = []
             _boxes = d.pop("boxes")
             for boxes_item_data in _boxes or []:
-                boxes_item = Box.from_dict(boxes_item_data)
+                boxes_item = Box.from_dict(boxes_item_data, strict=False)
 
                 boxes.append(boxes_item)
 
             return boxes
 
-        boxes = get_boxes() if "boxes" in d else cast(Union[Unset, List[Box]], UNSET)
+        try:
+            boxes = get_boxes()
+        except KeyError:
+            if strict:
+                raise
+            boxes = cast(Union[Unset, List[Box]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         boxes_paginated_list = cls(
             boxes=boxes,
