@@ -172,62 +172,90 @@ class ContainerWithCoordinates:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_grid_number() -> Union[Unset, float]:
             grid_number = d.pop("gridNumber")
             return grid_number
 
-        grid_number = get_grid_number() if "gridNumber" in d else cast(Union[Unset, float], UNSET)
+        try:
+            grid_number = get_grid_number()
+        except KeyError:
+            if strict:
+                raise
+            grid_number = cast(Union[Unset, float], UNSET)
 
         def get_grid_position() -> Union[Unset, str]:
             grid_position = d.pop("gridPosition")
             return grid_position
 
-        grid_position = get_grid_position() if "gridPosition" in d else cast(Union[Unset, str], UNSET)
+        try:
+            grid_position = get_grid_position()
+        except KeyError:
+            if strict:
+                raise
+            grid_position = cast(Union[Unset, str], UNSET)
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_barcode() -> Union[Unset, None, str]:
             barcode = d.pop("barcode")
             return barcode
 
-        barcode = get_barcode() if "barcode" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            barcode = get_barcode()
+        except KeyError:
+            if strict:
+                raise
+            barcode = cast(Union[Unset, None, str], UNSET)
 
         def get_checkout_record() -> Union[Unset, CheckoutRecord]:
-            checkout_record: Union[Unset, CheckoutRecord] = UNSET
+            checkout_record: Union[Unset, Union[Unset, CheckoutRecord]] = UNSET
             _checkout_record = d.pop("checkoutRecord")
+
             if not isinstance(_checkout_record, Unset):
                 checkout_record = CheckoutRecord.from_dict(_checkout_record)
 
             return checkout_record
 
-        checkout_record = (
-            get_checkout_record() if "checkoutRecord" in d else cast(Union[Unset, CheckoutRecord], UNSET)
-        )
+        try:
+            checkout_record = get_checkout_record()
+        except KeyError:
+            if strict:
+                raise
+            checkout_record = cast(Union[Unset, CheckoutRecord], UNSET)
 
         def get_contents() -> Union[Unset, List[ContainerContent]]:
             contents = []
             _contents = d.pop("contents")
             for contents_item_data in _contents or []:
-                contents_item = ContainerContent.from_dict(contents_item_data)
+                contents_item = ContainerContent.from_dict(contents_item_data, strict=False)
 
                 contents.append(contents_item)
 
             return contents
 
-        contents = get_contents() if "contents" in d else cast(Union[Unset, List[ContainerContent]], UNSET)
+        try:
+            contents = get_contents()
+        except KeyError:
+            if strict:
+                raise
+            contents = cast(Union[Unset, List[ContainerContent]], UNSET)
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
             created_at: Union[Unset, datetime.datetime] = UNSET
@@ -237,33 +265,55 @@ class ContainerWithCoordinates:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_creator() -> Union[Unset, UserSummary]:
-            creator: Union[Unset, UserSummary] = UNSET
+            creator: Union[Unset, Union[Unset, UserSummary]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = UserSummary.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, UserSummary], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, UserSummary], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_modified_at() -> Union[Unset, datetime.datetime]:
             modified_at: Union[Unset, datetime.datetime] = UNSET
@@ -273,79 +323,120 @@ class ContainerWithCoordinates:
 
             return modified_at
 
-        modified_at = get_modified_at() if "modifiedAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_parent_storage_id() -> Union[Unset, None, str]:
             parent_storage_id = d.pop("parentStorageId")
             return parent_storage_id
 
-        parent_storage_id = (
-            get_parent_storage_id() if "parentStorageId" in d else cast(Union[Unset, None, str], UNSET)
-        )
+        try:
+            parent_storage_id = get_parent_storage_id()
+        except KeyError:
+            if strict:
+                raise
+            parent_storage_id = cast(Union[Unset, None, str], UNSET)
 
         def get_parent_storage_schema() -> Union[Unset, None, SchemaSummary]:
             parent_storage_schema = None
             _parent_storage_schema = d.pop("parentStorageSchema")
+
             if _parent_storage_schema is not None and not isinstance(_parent_storage_schema, Unset):
                 parent_storage_schema = SchemaSummary.from_dict(_parent_storage_schema)
 
             return parent_storage_schema
 
-        parent_storage_schema = (
-            get_parent_storage_schema()
-            if "parentStorageSchema" in d
-            else cast(Union[Unset, None, SchemaSummary], UNSET)
-        )
+        try:
+            parent_storage_schema = get_parent_storage_schema()
+        except KeyError:
+            if strict:
+                raise
+            parent_storage_schema = cast(Union[Unset, None, SchemaSummary], UNSET)
 
         def get_project_id() -> Union[Unset, None, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, None, str], UNSET)
 
         def get_quantity() -> Union[Unset, ContainerQuantity]:
-            quantity: Union[Unset, ContainerQuantity] = UNSET
+            quantity: Union[Unset, Union[Unset, ContainerQuantity]] = UNSET
             _quantity = d.pop("quantity")
+
             if not isinstance(_quantity, Unset):
                 quantity = ContainerQuantity.from_dict(_quantity)
 
             return quantity
 
-        quantity = get_quantity() if "quantity" in d else cast(Union[Unset, ContainerQuantity], UNSET)
+        try:
+            quantity = get_quantity()
+        except KeyError:
+            if strict:
+                raise
+            quantity = cast(Union[Unset, ContainerQuantity], UNSET)
 
         def get_schema() -> Union[Unset, None, SchemaSummary]:
             schema = None
             _schema = d.pop("schema")
+
             if _schema is not None and not isinstance(_schema, Unset):
                 schema = SchemaSummary.from_dict(_schema)
 
             return schema
 
-        schema = get_schema() if "schema" in d else cast(Union[Unset, None, SchemaSummary], UNSET)
+        try:
+            schema = get_schema()
+        except KeyError:
+            if strict:
+                raise
+            schema = cast(Union[Unset, None, SchemaSummary], UNSET)
 
         def get_volume() -> Union[Unset, DeprecatedContainerVolumeForResponse]:
-            volume: Union[Unset, DeprecatedContainerVolumeForResponse] = UNSET
+            volume: Union[Unset, Union[Unset, DeprecatedContainerVolumeForResponse]] = UNSET
             _volume = d.pop("volume")
+
             if not isinstance(_volume, Unset):
                 volume = DeprecatedContainerVolumeForResponse.from_dict(_volume)
 
             return volume
 
-        volume = (
-            get_volume() if "volume" in d else cast(Union[Unset, DeprecatedContainerVolumeForResponse], UNSET)
-        )
+        try:
+            volume = get_volume()
+        except KeyError:
+            if strict:
+                raise
+            volume = cast(Union[Unset, DeprecatedContainerVolumeForResponse], UNSET)
 
         def get_web_url() -> Union[Unset, str]:
             web_url = d.pop("webURL")
             return web_url
 
-        web_url = get_web_url() if "webURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            web_url = get_web_url()
+        except KeyError:
+            if strict:
+                raise
+            web_url = cast(Union[Unset, str], UNSET)
 
         container_with_coordinates = cls(
             grid_number=grid_number,
