@@ -35,22 +35,27 @@ class CustomEntitiesBulkCreateRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_custom_entities() -> List[CustomEntityBulkCreate]:
             custom_entities = []
             _custom_entities = d.pop("customEntities")
             for custom_entities_item_data in _custom_entities:
-                custom_entities_item = CustomEntityBulkCreate.from_dict(custom_entities_item_data)
+                custom_entities_item = CustomEntityBulkCreate.from_dict(
+                    custom_entities_item_data, strict=False
+                )
 
                 custom_entities.append(custom_entities_item)
 
             return custom_entities
 
-        custom_entities = (
-            get_custom_entities() if "customEntities" in d else cast(List[CustomEntityBulkCreate], UNSET)
-        )
+        try:
+            custom_entities = get_custom_entities()
+        except KeyError:
+            if strict:
+                raise
+            custom_entities = cast(List[CustomEntityBulkCreate], UNSET)
 
         custom_entities_bulk_create_request = cls(
             custom_entities=custom_entities,
