@@ -30,7 +30,7 @@ class CustomEntitiesUnarchive:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_custom_entity_ids() -> List[str]:
@@ -38,7 +38,12 @@ class CustomEntitiesUnarchive:
 
             return custom_entity_ids
 
-        custom_entity_ids = get_custom_entity_ids() if "customEntityIds" in d else cast(List[str], UNSET)
+        try:
+            custom_entity_ids = get_custom_entity_ids()
+        except KeyError:
+            if strict:
+                raise
+            custom_entity_ids = cast(List[str], UNSET)
 
         custom_entities_unarchive = cls(
             custom_entity_ids=custom_entity_ids,
