@@ -46,28 +46,36 @@ class EntitySchemasPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entity_schemas() -> Union[Unset, List[EntitySchema]]:
             entity_schemas = []
             _entity_schemas = d.pop("entitySchemas")
             for entity_schemas_item_data in _entity_schemas or []:
-                entity_schemas_item = EntitySchema.from_dict(entity_schemas_item_data)
+                entity_schemas_item = EntitySchema.from_dict(entity_schemas_item_data, strict=False)
 
                 entity_schemas.append(entity_schemas_item)
 
             return entity_schemas
 
-        entity_schemas = (
-            get_entity_schemas() if "entitySchemas" in d else cast(Union[Unset, List[EntitySchema]], UNSET)
-        )
+        try:
+            entity_schemas = get_entity_schemas()
+        except KeyError:
+            if strict:
+                raise
+            entity_schemas = cast(Union[Unset, List[EntitySchema]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         entity_schemas_paginated_list = cls(
             entity_schemas=entity_schemas,
