@@ -46,26 +46,36 @@ class EntriesPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entries() -> Union[Unset, List[Entry]]:
             entries = []
             _entries = d.pop("entries")
             for entries_item_data in _entries or []:
-                entries_item = Entry.from_dict(entries_item_data)
+                entries_item = Entry.from_dict(entries_item_data, strict=False)
 
                 entries.append(entries_item)
 
             return entries
 
-        entries = get_entries() if "entries" in d else cast(Union[Unset, List[Entry]], UNSET)
+        try:
+            entries = get_entries()
+        except KeyError:
+            if strict:
+                raise
+            entries = cast(Union[Unset, List[Entry]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         entries_paginated_list = cls(
             entries=entries,
