@@ -82,18 +82,24 @@ class EntryCreatedEvent:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entry() -> Union[Unset, Entry]:
-            entry: Union[Unset, Entry] = UNSET
+            entry: Union[Unset, Union[Unset, Entry]] = UNSET
             _entry = d.pop("entry")
+
             if not isinstance(_entry, Unset):
                 entry = Entry.from_dict(_entry)
 
             return entry
 
-        entry = get_entry() if "entry" in d else cast(Union[Unset, Entry], UNSET)
+        try:
+            entry = get_entry()
+        except KeyError:
+            if strict:
+                raise
+            entry = cast(Union[Unset, Entry], UNSET)
 
         def get_event_type() -> Union[Unset, EntryCreatedEventEventType]:
             event_type = UNSET
@@ -106,9 +112,12 @@ class EntryCreatedEvent:
 
             return event_type
 
-        event_type = (
-            get_event_type() if "eventType" in d else cast(Union[Unset, EntryCreatedEventEventType], UNSET)
-        )
+        try:
+            event_type = get_event_type()
+        except KeyError:
+            if strict:
+                raise
+            event_type = cast(Union[Unset, EntryCreatedEventEventType], UNSET)
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
             created_at: Union[Unset, datetime.datetime] = UNSET
@@ -118,38 +127,62 @@ class EntryCreatedEvent:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_deprecated() -> Union[Unset, bool]:
             deprecated = d.pop("deprecated")
             return deprecated
 
-        deprecated = get_deprecated() if "deprecated" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            deprecated = get_deprecated()
+        except KeyError:
+            if strict:
+                raise
+            deprecated = cast(Union[Unset, bool], UNSET)
 
         def get_excluded_properties() -> Union[Unset, List[str]]:
             excluded_properties = cast(List[str], d.pop("excludedProperties"))
 
             return excluded_properties
 
-        excluded_properties = (
-            get_excluded_properties() if "excludedProperties" in d else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            excluded_properties = get_excluded_properties()
+        except KeyError:
+            if strict:
+                raise
+            excluded_properties = cast(Union[Unset, List[str]], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_schema() -> Union[Unset, None, EventBaseSchema]:
             schema = None
             _schema = d.pop("schema")
+
             if _schema is not None and not isinstance(_schema, Unset):
                 schema = EventBaseSchema.from_dict(_schema)
 
             return schema
 
-        schema = get_schema() if "schema" in d else cast(Union[Unset, None, EventBaseSchema], UNSET)
+        try:
+            schema = get_schema()
+        except KeyError:
+            if strict:
+                raise
+            schema = cast(Union[Unset, None, EventBaseSchema], UNSET)
 
         entry_created_event = cls(
             entry=entry,
