@@ -35,20 +35,30 @@ class FeatureLibraryUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_description() -> Union[Unset, str]:
             description = d.pop("description")
             return description
 
-        description = get_description() if "description" in d else cast(Union[Unset, str], UNSET)
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         feature_library_update = cls(
             description=description,
