@@ -44,7 +44,7 @@ class FindMatchingRegionsAsyncTaskResponse:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_aa_sequence_matches() -> Union[
@@ -55,7 +55,7 @@ class FindMatchingRegionsAsyncTaskResponse:
             for aa_sequence_matches_item_data in _aa_sequence_matches or []:
                 aa_sequence_matches_item = (
                     FindMatchingRegionsAsyncTaskResponseAaSequenceMatchesItem.from_dict(
-                        aa_sequence_matches_item_data
+                        aa_sequence_matches_item_data, strict=False
                     )
                 )
 
@@ -63,11 +63,14 @@ class FindMatchingRegionsAsyncTaskResponse:
 
             return aa_sequence_matches
 
-        aa_sequence_matches = (
-            get_aa_sequence_matches()
-            if "aaSequenceMatches" in d
-            else cast(Union[Unset, List[FindMatchingRegionsAsyncTaskResponseAaSequenceMatchesItem]], UNSET)
-        )
+        try:
+            aa_sequence_matches = get_aa_sequence_matches()
+        except KeyError:
+            if strict:
+                raise
+            aa_sequence_matches = cast(
+                Union[Unset, List[FindMatchingRegionsAsyncTaskResponseAaSequenceMatchesItem]], UNSET
+            )
 
         find_matching_regions_async_task_response = cls(
             aa_sequence_matches=aa_sequence_matches,
