@@ -63,7 +63,7 @@ class LegacyWorkflow:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
@@ -74,37 +74,67 @@ class LegacyWorkflow:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_description() -> Union[Unset, None, str]:
             description = d.pop("description")
             return description
 
-        description = get_description() if "description" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, None, str], UNSET)
 
         def get_display_id() -> Union[Unset, str]:
             display_id = d.pop("displayId")
             return display_id
 
-        display_id = get_display_id() if "displayId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            display_id = get_display_id()
+        except KeyError:
+            if strict:
+                raise
+            display_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_project_id() -> Union[Unset, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, str], UNSET)
 
         legacy_workflow = cls(
             created_at=created_at,
