@@ -56,7 +56,7 @@ class LegacyWorkflowStageRun:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
@@ -67,19 +67,34 @@ class LegacyWorkflowStageRun:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_status() -> Union[Unset, LegacyWorkflowStageRunStatus]:
             status = UNSET
@@ -92,7 +107,12 @@ class LegacyWorkflowStageRun:
 
             return status
 
-        status = get_status() if "status" in d else cast(Union[Unset, LegacyWorkflowStageRunStatus], UNSET)
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(Union[Unset, LegacyWorkflowStageRunStatus], UNSET)
 
         legacy_workflow_stage_run = cls(
             created_at=created_at,
