@@ -8,6 +8,8 @@ from ..extensions import Enums
 class ListAssayResultsSort(Enums.KnownString):
     CREATEDATASC = "createdAt:asc"
     CREATEDATDESC = "createdAt:desc"
+    MODIFIEDATASC = "modifiedAt:asc"
+    MODIFIEDATDESC = "modifiedAt:desc"
 
     def __str__(self) -> str:
         return str(self.value)
