@@ -39,12 +39,11 @@ class LocationCreate:
         parent_storage_id = self._parent_storage_id
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update(
-            {
-                "name": name,
-                "schemaId": schema_id,
-            }
-        )
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
+        if name is not UNSET:
+            field_dict["name"] = name
+        if schema_id is not UNSET:
+            field_dict["schemaId"] = schema_id
         if barcode is not UNSET:
             field_dict["barcode"] = barcode
         if fields is not UNSET:
@@ -55,44 +54,68 @@ class LocationCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
         def get_schema_id() -> str:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(str, UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(str, UNSET)
 
         def get_barcode() -> Union[Unset, str]:
             barcode = d.pop("barcode")
             return barcode
 
-        barcode = get_barcode() if "barcode" in d else cast(Union[Unset, str], UNSET)
+        try:
+            barcode = get_barcode()
+        except KeyError:
+            if strict:
+                raise
+            barcode = cast(Union[Unset, str], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_parent_storage_id() -> Union[Unset, str]:
             parent_storage_id = d.pop("parentStorageId")
             return parent_storage_id
 
-        parent_storage_id = (
-            get_parent_storage_id() if "parentStorageId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            parent_storage_id = get_parent_storage_id()
+        except KeyError:
+            if strict:
+                raise
+            parent_storage_id = cast(Union[Unset, str], UNSET)
 
         location_create = cls(
             name=name,
