@@ -35,7 +35,7 @@ class MixturesArchivalChange:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_mixture_ids() -> Union[Unset, List[str]]:
@@ -43,7 +43,12 @@ class MixturesArchivalChange:
 
             return mixture_ids
 
-        mixture_ids = get_mixture_ids() if "mixtureIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            mixture_ids = get_mixture_ids()
+        except KeyError:
+            if strict:
+                raise
+            mixture_ids = cast(Union[Unset, List[str]], UNSET)
 
         mixtures_archival_change = cls(
             mixture_ids=mixture_ids,
