@@ -24,8 +24,9 @@ class MultipleContainersTransferSourceConcentration:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
+
         multiple_containers_transfer_source_concentration = cls()
 
         multiple_containers_transfer_source_concentration.additional_properties = d
