@@ -36,18 +36,24 @@ class OAuthUnauthorizedError:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_error() -> Union[Unset, OAuthUnauthorizedErrorError]:
-            error: Union[Unset, OAuthUnauthorizedErrorError] = UNSET
+            error: Union[Unset, Union[Unset, OAuthUnauthorizedErrorError]] = UNSET
             _error = d.pop("error")
+
             if not isinstance(_error, Unset):
                 error = OAuthUnauthorizedErrorError.from_dict(_error)
 
             return error
 
-        error = get_error() if "error" in d else cast(Union[Unset, OAuthUnauthorizedErrorError], UNSET)
+        try:
+            error = get_error()
+        except KeyError:
+            if strict:
+                raise
+            error = cast(Union[Unset, OAuthUnauthorizedErrorError], UNSET)
 
         o_auth_unauthorized_error = cls(
             error=error,
