@@ -71,7 +71,7 @@ class OligoCreate:
         schema_id = self._schema_id
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if entity_registry_id is not UNSET:
             field_dict["entityRegistryId"] = entity_registry_id
         if folder_id is not UNSET:
@@ -98,25 +98,33 @@ class OligoCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entity_registry_id() -> Union[Unset, str]:
             entity_registry_id = d.pop("entityRegistryId")
             return entity_registry_id
 
-        entity_registry_id = (
-            get_entity_registry_id() if "entityRegistryId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            entity_registry_id = get_entity_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            entity_registry_id = cast(Union[Unset, str], UNSET)
 
         def get_folder_id() -> Union[Unset, str]:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(Union[Unset, str], UNSET)
 
         def get_naming_strategy() -> Union[Unset, NamingStrategy]:
-            naming_strategy = None
+            naming_strategy = UNSET
             _naming_strategy = d.pop("namingStrategy")
             if _naming_strategy is not None and _naming_strategy is not UNSET:
                 try:
@@ -126,69 +134,112 @@ class OligoCreate:
 
             return naming_strategy
 
-        naming_strategy = (
-            get_naming_strategy() if "namingStrategy" in d else cast(Union[Unset, NamingStrategy], UNSET)
-        )
+        try:
+            naming_strategy = get_naming_strategy()
+        except KeyError:
+            if strict:
+                raise
+            naming_strategy = cast(Union[Unset, NamingStrategy], UNSET)
 
         def get_registry_id() -> Union[Unset, str]:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(Union[Unset, str], UNSET)
 
         def get_aliases() -> Union[Unset, List[str]]:
             aliases = cast(List[str], d.pop("aliases"))
 
             return aliases
 
-        aliases = get_aliases() if "aliases" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            aliases = get_aliases()
+        except KeyError:
+            if strict:
+                raise
+            aliases = cast(Union[Unset, List[str]], UNSET)
 
         def get_author_ids() -> Union[Unset, List[str]]:
             author_ids = cast(List[str], d.pop("authorIds"))
 
             return author_ids
 
-        author_ids = get_author_ids() if "authorIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            author_ids = get_author_ids()
+        except KeyError:
+            if strict:
+                raise
+            author_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_bases() -> Union[Unset, str]:
             bases = d.pop("bases")
             return bases
 
-        bases = get_bases() if "bases" in d else cast(Union[Unset, str], UNSET)
+        try:
+            bases = get_bases()
+        except KeyError:
+            if strict:
+                raise
+            bases = cast(Union[Unset, str], UNSET)
 
         def get_custom_fields() -> Union[Unset, CustomFields]:
-            custom_fields: Union[Unset, CustomFields] = UNSET
+            custom_fields: Union[Unset, Union[Unset, CustomFields]] = UNSET
             _custom_fields = d.pop("customFields")
+
             if not isinstance(_custom_fields, Unset):
                 custom_fields = CustomFields.from_dict(_custom_fields)
 
             return custom_fields
 
-        custom_fields = (
-            get_custom_fields() if "customFields" in d else cast(Union[Unset, CustomFields], UNSET)
-        )
+        try:
+            custom_fields = get_custom_fields()
+        except KeyError:
+            if strict:
+                raise
+            custom_fields = cast(Union[Unset, CustomFields], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_schema_id() -> Union[Unset, str]:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(Union[Unset, str], UNSET)
 
         oligo_create = cls(
             entity_registry_id=entity_registry_id,
