@@ -54,34 +54,40 @@ class RequestResponseSamplesItem:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_batch() -> Union[Unset, None, RequestResponseSamplesItemBatch]:
             batch = None
             _batch = d.pop("batch")
+
             if _batch is not None and not isinstance(_batch, Unset):
                 batch = RequestResponseSamplesItemBatch.from_dict(_batch)
 
             return batch
 
-        batch = (
-            get_batch() if "batch" in d else cast(Union[Unset, None, RequestResponseSamplesItemBatch], UNSET)
-        )
+        try:
+            batch = get_batch()
+        except KeyError:
+            if strict:
+                raise
+            batch = cast(Union[Unset, None, RequestResponseSamplesItemBatch], UNSET)
 
         def get_entity() -> Union[Unset, None, RequestResponseSamplesItemEntity]:
             entity = None
             _entity = d.pop("entity")
+
             if _entity is not None and not isinstance(_entity, Unset):
                 entity = RequestResponseSamplesItemEntity.from_dict(_entity)
 
             return entity
 
-        entity = (
-            get_entity()
-            if "entity" in d
-            else cast(Union[Unset, None, RequestResponseSamplesItemEntity], UNSET)
-        )
+        try:
+            entity = get_entity()
+        except KeyError:
+            if strict:
+                raise
+            entity = cast(Union[Unset, None, RequestResponseSamplesItemEntity], UNSET)
 
         def get_status() -> Union[Unset, RequestResponseSamplesItemStatus]:
             status = UNSET
@@ -94,9 +100,12 @@ class RequestResponseSamplesItem:
 
             return status
 
-        status = (
-            get_status() if "status" in d else cast(Union[Unset, RequestResponseSamplesItemStatus], UNSET)
-        )
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(Union[Unset, RequestResponseSamplesItemStatus], UNSET)
 
         request_response_samples_item = cls(
             batch=batch,
