@@ -41,24 +41,35 @@ class RequestSampleGroup:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_samples() -> Union[Unset, RequestSampleGroupSamples]:
-            samples: Union[Unset, RequestSampleGroupSamples] = UNSET
+            samples: Union[Unset, Union[Unset, RequestSampleGroupSamples]] = UNSET
             _samples = d.pop("samples")
+
             if not isinstance(_samples, Unset):
                 samples = RequestSampleGroupSamples.from_dict(_samples)
 
             return samples
 
-        samples = get_samples() if "samples" in d else cast(Union[Unset, RequestSampleGroupSamples], UNSET)
+        try:
+            samples = get_samples()
+        except KeyError:
+            if strict:
+                raise
+            samples = cast(Union[Unset, RequestSampleGroupSamples], UNSET)
 
         request_sample_group = cls(
             id=id,
