@@ -148,7 +148,7 @@ class RnaSequence:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if aliases is not UNSET:
             field_dict["aliases"] = aliases
         if annotations is not UNSET:
@@ -197,7 +197,7 @@ class RnaSequence:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_aliases() -> Union[Unset, List[str]]:
@@ -205,45 +205,67 @@ class RnaSequence:
 
             return aliases
 
-        aliases = get_aliases() if "aliases" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            aliases = get_aliases()
+        except KeyError:
+            if strict:
+                raise
+            aliases = cast(Union[Unset, List[str]], UNSET)
 
         def get_annotations() -> Union[Unset, List[RnaAnnotation]]:
             annotations = []
             _annotations = d.pop("annotations")
             for annotations_item_data in _annotations or []:
-                annotations_item = RnaAnnotation.from_dict(annotations_item_data)
+                annotations_item = RnaAnnotation.from_dict(annotations_item_data, strict=False)
 
                 annotations.append(annotations_item)
 
             return annotations
 
-        annotations = (
-            get_annotations() if "annotations" in d else cast(Union[Unset, List[RnaAnnotation]], UNSET)
-        )
+        try:
+            annotations = get_annotations()
+        except KeyError:
+            if strict:
+                raise
+            annotations = cast(Union[Unset, List[RnaAnnotation]], UNSET)
 
         def get_api_url() -> Union[Unset, str]:
             api_url = d.pop("apiURL")
             return api_url
 
-        api_url = get_api_url() if "apiURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            api_url = get_api_url()
+        except KeyError:
+            if strict:
+                raise
+            api_url = cast(Union[Unset, str], UNSET)
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_bases() -> Union[Unset, str]:
             bases = d.pop("bases")
             return bases
 
-        bases = get_bases() if "bases" in d else cast(Union[Unset, str], UNSET)
+        try:
+            bases = get_bases()
+        except KeyError:
+            if strict:
+                raise
+            bases = cast(Union[Unset, str], UNSET)
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
             created_at: Union[Unset, datetime.datetime] = UNSET
@@ -253,71 +275,115 @@ class RnaSequence:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_creator() -> Union[Unset, UserSummary]:
-            creator: Union[Unset, UserSummary] = UNSET
+            creator: Union[Unset, Union[Unset, UserSummary]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = UserSummary.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, UserSummary], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, UserSummary], UNSET)
 
         def get_custom_fields() -> Union[Unset, CustomFields]:
-            custom_fields: Union[Unset, CustomFields] = UNSET
+            custom_fields: Union[Unset, Union[Unset, CustomFields]] = UNSET
             _custom_fields = d.pop("customFields")
+
             if not isinstance(_custom_fields, Unset):
                 custom_fields = CustomFields.from_dict(_custom_fields)
 
             return custom_fields
 
-        custom_fields = (
-            get_custom_fields() if "customFields" in d else cast(Union[Unset, CustomFields], UNSET)
-        )
+        try:
+            custom_fields = get_custom_fields()
+        except KeyError:
+            if strict:
+                raise
+            custom_fields = cast(Union[Unset, CustomFields], UNSET)
 
         def get_entity_registry_id() -> Union[Unset, None, str]:
             entity_registry_id = d.pop("entityRegistryId")
             return entity_registry_id
 
-        entity_registry_id = (
-            get_entity_registry_id() if "entityRegistryId" in d else cast(Union[Unset, None, str], UNSET)
-        )
+        try:
+            entity_registry_id = get_entity_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            entity_registry_id = cast(Union[Unset, None, str], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_folder_id() -> Union[Unset, None, str]:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(Union[Unset, None, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_is_circular() -> Union[Unset, bool]:
             is_circular = d.pop("isCircular")
             return is_circular
 
-        is_circular = get_is_circular() if "isCircular" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_circular = get_is_circular()
+        except KeyError:
+            if strict:
+                raise
+            is_circular = cast(Union[Unset, bool], UNSET)
 
         def get_length() -> Union[Unset, int]:
             length = d.pop("length")
             return length
 
-        length = get_length() if "length" in d else cast(Union[Unset, int], UNSET)
+        try:
+            length = get_length()
+        except KeyError:
+            if strict:
+                raise
+            length = cast(Union[Unset, int], UNSET)
 
         def get_modified_at() -> Union[Unset, datetime.datetime]:
             modified_at: Union[Unset, datetime.datetime] = UNSET
@@ -327,75 +393,111 @@ class RnaSequence:
 
             return modified_at
 
-        modified_at = get_modified_at() if "modifiedAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_primers() -> Union[Unset, List[Primer]]:
             primers = []
             _primers = d.pop("primers")
             for primers_item_data in _primers or []:
-                primers_item = Primer.from_dict(primers_item_data)
+                primers_item = Primer.from_dict(primers_item_data, strict=False)
 
                 primers.append(primers_item)
 
             return primers
 
-        primers = get_primers() if "primers" in d else cast(Union[Unset, List[Primer]], UNSET)
+        try:
+            primers = get_primers()
+        except KeyError:
+            if strict:
+                raise
+            primers = cast(Union[Unset, List[Primer]], UNSET)
 
         def get_registration_origin() -> Union[Unset, None, RegistrationOrigin]:
             registration_origin = None
             _registration_origin = d.pop("registrationOrigin")
+
             if _registration_origin is not None and not isinstance(_registration_origin, Unset):
                 registration_origin = RegistrationOrigin.from_dict(_registration_origin)
 
             return registration_origin
 
-        registration_origin = (
-            get_registration_origin()
-            if "registrationOrigin" in d
-            else cast(Union[Unset, None, RegistrationOrigin], UNSET)
-        )
+        try:
+            registration_origin = get_registration_origin()
+        except KeyError:
+            if strict:
+                raise
+            registration_origin = cast(Union[Unset, None, RegistrationOrigin], UNSET)
 
         def get_registry_id() -> Union[Unset, None, str]:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(Union[Unset, None, str], UNSET)
 
         def get_schema() -> Union[Unset, None, SchemaSummary]:
             schema = None
             _schema = d.pop("schema")
+
             if _schema is not None and not isinstance(_schema, Unset):
                 schema = SchemaSummary.from_dict(_schema)
 
             return schema
 
-        schema = get_schema() if "schema" in d else cast(Union[Unset, None, SchemaSummary], UNSET)
+        try:
+            schema = get_schema()
+        except KeyError:
+            if strict:
+                raise
+            schema = cast(Union[Unset, None, SchemaSummary], UNSET)
 
         def get_translations() -> Union[Unset, List[Translation]]:
             translations = []
             _translations = d.pop("translations")
             for translations_item_data in _translations or []:
-                translations_item = Translation.from_dict(translations_item_data)
+                translations_item = Translation.from_dict(translations_item_data, strict=False)
 
                 translations.append(translations_item)
 
             return translations
 
-        translations = (
-            get_translations() if "translations" in d else cast(Union[Unset, List[Translation]], UNSET)
-        )
+        try:
+            translations = get_translations()
+        except KeyError:
+            if strict:
+                raise
+            translations = cast(Union[Unset, List[Translation]], UNSET)
 
         def get_web_url() -> Union[Unset, str]:
             web_url = d.pop("webURL")
             return web_url
 
-        web_url = get_web_url() if "webURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            web_url = get_web_url()
+        except KeyError:
+            if strict:
+                raise
+            web_url = cast(Union[Unset, str], UNSET)
 
         rna_sequence = cls(
             aliases=aliases,
