@@ -122,7 +122,7 @@ class RnaSequenceBaseRequestForCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_aliases() -> Union[Unset, List[str]]:
@@ -130,106 +130,162 @@ class RnaSequenceBaseRequestForCreate:
 
             return aliases
 
-        aliases = get_aliases() if "aliases" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            aliases = get_aliases()
+        except KeyError:
+            if strict:
+                raise
+            aliases = cast(Union[Unset, List[str]], UNSET)
 
         def get_annotations() -> Union[Unset, List[RnaAnnotation]]:
             annotations = []
             _annotations = d.pop("annotations")
             for annotations_item_data in _annotations or []:
-                annotations_item = RnaAnnotation.from_dict(annotations_item_data)
+                annotations_item = RnaAnnotation.from_dict(annotations_item_data, strict=False)
 
                 annotations.append(annotations_item)
 
             return annotations
 
-        annotations = (
-            get_annotations() if "annotations" in d else cast(Union[Unset, List[RnaAnnotation]], UNSET)
-        )
+        try:
+            annotations = get_annotations()
+        except KeyError:
+            if strict:
+                raise
+            annotations = cast(Union[Unset, List[RnaAnnotation]], UNSET)
 
         def get_author_ids() -> Union[Unset, List[str]]:
             author_ids = cast(List[str], d.pop("authorIds"))
 
             return author_ids
 
-        author_ids = get_author_ids() if "authorIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            author_ids = get_author_ids()
+        except KeyError:
+            if strict:
+                raise
+            author_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_bases() -> Union[Unset, str]:
             bases = d.pop("bases")
             return bases
 
-        bases = get_bases() if "bases" in d else cast(Union[Unset, str], UNSET)
+        try:
+            bases = get_bases()
+        except KeyError:
+            if strict:
+                raise
+            bases = cast(Union[Unset, str], UNSET)
 
         def get_custom_fields() -> Union[Unset, CustomFields]:
-            custom_fields: Union[Unset, CustomFields] = UNSET
+            custom_fields: Union[Unset, Union[Unset, CustomFields]] = UNSET
             _custom_fields = d.pop("customFields")
+
             if not isinstance(_custom_fields, Unset):
                 custom_fields = CustomFields.from_dict(_custom_fields)
 
             return custom_fields
 
-        custom_fields = (
-            get_custom_fields() if "customFields" in d else cast(Union[Unset, CustomFields], UNSET)
-        )
+        try:
+            custom_fields = get_custom_fields()
+        except KeyError:
+            if strict:
+                raise
+            custom_fields = cast(Union[Unset, CustomFields], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_folder_id() -> Union[Unset, str]:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(Union[Unset, str], UNSET)
 
         def get_is_circular() -> Union[Unset, bool]:
             is_circular = d.pop("isCircular")
             return is_circular
 
-        is_circular = get_is_circular() if "isCircular" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_circular = get_is_circular()
+        except KeyError:
+            if strict:
+                raise
+            is_circular = cast(Union[Unset, bool], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_primers() -> Union[Unset, List[Primer]]:
             primers = []
             _primers = d.pop("primers")
             for primers_item_data in _primers or []:
-                primers_item = Primer.from_dict(primers_item_data)
+                primers_item = Primer.from_dict(primers_item_data, strict=False)
 
                 primers.append(primers_item)
 
             return primers
 
-        primers = get_primers() if "primers" in d else cast(Union[Unset, List[Primer]], UNSET)
+        try:
+            primers = get_primers()
+        except KeyError:
+            if strict:
+                raise
+            primers = cast(Union[Unset, List[Primer]], UNSET)
 
         def get_schema_id() -> Union[Unset, str]:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(Union[Unset, str], UNSET)
 
         def get_translations() -> Union[Unset, List[Translation]]:
             translations = []
             _translations = d.pop("translations")
             for translations_item_data in _translations or []:
-                translations_item = Translation.from_dict(translations_item_data)
+                translations_item = Translation.from_dict(translations_item_data, strict=False)
 
                 translations.append(translations_item)
 
             return translations
 
-        translations = (
-            get_translations() if "translations" in d else cast(Union[Unset, List[Translation]], UNSET)
-        )
+        try:
+            translations = get_translations()
+        except KeyError:
+            if strict:
+                raise
+            translations = cast(Union[Unset, List[Translation]], UNSET)
 
         rna_sequence_base_request_for_create = cls(
             aliases=aliases,
