@@ -146,7 +146,7 @@ class WorkflowTask:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_execution_type() -> Union[Unset, WorkflowTaskExecutionType]:
@@ -160,91 +160,125 @@ class WorkflowTask:
 
             return execution_type
 
-        execution_type = (
-            get_execution_type()
-            if "executionType" in d
-            else cast(Union[Unset, WorkflowTaskExecutionType], UNSET)
-        )
+        try:
+            execution_type = get_execution_type()
+        except KeyError:
+            if strict:
+                raise
+            execution_type = cast(Union[Unset, WorkflowTaskExecutionType], UNSET)
 
         def get_assignee() -> Union[Unset, None, UserSummary]:
             assignee = None
             _assignee = d.pop("assignee")
+
             if _assignee is not None and not isinstance(_assignee, Unset):
                 assignee = UserSummary.from_dict(_assignee)
 
             return assignee
 
-        assignee = get_assignee() if "assignee" in d else cast(Union[Unset, None, UserSummary], UNSET)
+        try:
+            assignee = get_assignee()
+        except KeyError:
+            if strict:
+                raise
+            assignee = cast(Union[Unset, None, UserSummary], UNSET)
 
         def get_cloned_from() -> Union[Unset, None, WorkflowTaskSummary]:
             cloned_from = None
             _cloned_from = d.pop("clonedFrom")
+
             if _cloned_from is not None and not isinstance(_cloned_from, Unset):
                 cloned_from = WorkflowTaskSummary.from_dict(_cloned_from)
 
             return cloned_from
 
-        cloned_from = (
-            get_cloned_from() if "clonedFrom" in d else cast(Union[Unset, None, WorkflowTaskSummary], UNSET)
-        )
+        try:
+            cloned_from = get_cloned_from()
+        except KeyError:
+            if strict:
+                raise
+            cloned_from = cast(Union[Unset, None, WorkflowTaskSummary], UNSET)
 
         def get_creation_origin() -> Union[Unset, CreationOrigin]:
-            creation_origin: Union[Unset, CreationOrigin] = UNSET
+            creation_origin: Union[Unset, Union[Unset, CreationOrigin]] = UNSET
             _creation_origin = d.pop("creationOrigin")
+
             if not isinstance(_creation_origin, Unset):
                 creation_origin = CreationOrigin.from_dict(_creation_origin)
 
             return creation_origin
 
-        creation_origin = (
-            get_creation_origin() if "creationOrigin" in d else cast(Union[Unset, CreationOrigin], UNSET)
-        )
+        try:
+            creation_origin = get_creation_origin()
+        except KeyError:
+            if strict:
+                raise
+            creation_origin = cast(Union[Unset, CreationOrigin], UNSET)
 
         def get_creator() -> Union[Unset, UserSummary]:
-            creator: Union[Unset, UserSummary] = UNSET
+            creator: Union[Unset, Union[Unset, UserSummary]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = UserSummary.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, UserSummary], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, UserSummary], UNSET)
 
         def get_execution_origin() -> Union[Unset, None, WorkflowTaskExecutionOrigin]:
             execution_origin = None
             _execution_origin = d.pop("executionOrigin")
+
             if _execution_origin is not None and not isinstance(_execution_origin, Unset):
                 execution_origin = WorkflowTaskExecutionOrigin.from_dict(_execution_origin)
 
             return execution_origin
 
-        execution_origin = (
-            get_execution_origin()
-            if "executionOrigin" in d
-            else cast(Union[Unset, None, WorkflowTaskExecutionOrigin], UNSET)
-        )
+        try:
+            execution_origin = get_execution_origin()
+        except KeyError:
+            if strict:
+                raise
+            execution_origin = cast(Union[Unset, None, WorkflowTaskExecutionOrigin], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_outputs() -> Union[Unset, List[WorkflowOutputSummary]]:
             outputs = []
             _outputs = d.pop("outputs")
             for outputs_item_data in _outputs or []:
-                outputs_item = WorkflowOutputSummary.from_dict(outputs_item_data)
+                outputs_item = WorkflowOutputSummary.from_dict(outputs_item_data, strict=False)
 
                 outputs.append(outputs_item)
 
             return outputs
 
-        outputs = get_outputs() if "outputs" in d else cast(Union[Unset, List[WorkflowOutputSummary]], UNSET)
+        try:
+            outputs = get_outputs()
+        except KeyError:
+            if strict:
+                raise
+            outputs = cast(Union[Unset, List[WorkflowOutputSummary]], UNSET)
 
         def get_scheduled_on() -> Union[Unset, None, datetime.date]:
             scheduled_on: Union[Unset, None, datetime.date] = UNSET
@@ -254,51 +288,77 @@ class WorkflowTask:
 
             return scheduled_on
 
-        scheduled_on = (
-            get_scheduled_on() if "scheduledOn" in d else cast(Union[Unset, None, datetime.date], UNSET)
-        )
+        try:
+            scheduled_on = get_scheduled_on()
+        except KeyError:
+            if strict:
+                raise
+            scheduled_on = cast(Union[Unset, None, datetime.date], UNSET)
 
         def get_status() -> Union[Unset, WorkflowTaskStatus]:
-            status: Union[Unset, WorkflowTaskStatus] = UNSET
+            status: Union[Unset, Union[Unset, WorkflowTaskStatus]] = UNSET
             _status = d.pop("status")
+
             if not isinstance(_status, Unset):
                 status = WorkflowTaskStatus.from_dict(_status)
 
             return status
 
-        status = get_status() if "status" in d else cast(Union[Unset, WorkflowTaskStatus], UNSET)
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(Union[Unset, WorkflowTaskStatus], UNSET)
 
         def get_web_url() -> Union[Unset, str]:
             web_url = d.pop("webURL")
             return web_url
 
-        web_url = get_web_url() if "webURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            web_url = get_web_url()
+        except KeyError:
+            if strict:
+                raise
+            web_url = cast(Union[Unset, str], UNSET)
 
         def get_workflow_task_group() -> Union[Unset, WorkflowTaskGroupSummary]:
-            workflow_task_group: Union[Unset, WorkflowTaskGroupSummary] = UNSET
+            workflow_task_group: Union[Unset, Union[Unset, WorkflowTaskGroupSummary]] = UNSET
             _workflow_task_group = d.pop("workflowTaskGroup")
+
             if not isinstance(_workflow_task_group, Unset):
                 workflow_task_group = WorkflowTaskGroupSummary.from_dict(_workflow_task_group)
 
             return workflow_task_group
 
-        workflow_task_group = (
-            get_workflow_task_group()
-            if "workflowTaskGroup" in d
-            else cast(Union[Unset, WorkflowTaskGroupSummary], UNSET)
-        )
+        try:
+            workflow_task_group = get_workflow_task_group()
+        except KeyError:
+            if strict:
+                raise
+            workflow_task_group = cast(Union[Unset, WorkflowTaskGroupSummary], UNSET)
 
         def get_display_id() -> Union[Unset, str]:
             display_id = d.pop("displayId")
             return display_id
 
-        display_id = get_display_id() if "displayId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            display_id = get_display_id()
+        except KeyError:
+            if strict:
+                raise
+            display_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         workflow_task = cls(
             execution_type=execution_type,
