@@ -35,11 +35,11 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[Union[File, BadRequestError]]:
     if response.status_code == 200:
-        response_200 = File.from_dict(response.json())
+        response_200 = File.from_dict(response.json(), strict=False)
 
         return response_200
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     return None
@@ -76,8 +76,8 @@ def sync(
     client: Client,
     json_body: FileCreate,
 ) -> Optional[Union[File, BadRequestError]]:
-    """Create a file of a supported type. Currently, we support these file extensions: .htm, .html, .shtml
-    (HTML); .jmp; .jpe, .jpeg, .jpg (JPEG); .jrp; and .png.
+    """Create a file of a supported type. Currently, we support these file extensions: .csv; .html;
+    .jmp, .jrn, .jrp (JMP), .jpeg, .jpg (JPEG); .png; and .txt.
 
     A successful file upload requires 3 calls in serial:
     1. [Create a file](#/Analyses/createFile), this endpoint, which returns an S3 `PUT` URL for the 2nd
@@ -87,7 +87,7 @@ def sync(
        ```bash
        curl -H \"x-amz-server-side-encryption: AES256\" -X PUT -T <LOCAL_FILE> -L <S3_PUT_URL>
        ```
-    3. [Update the file](#/Analyses/createFile), which marks the upload as `SUCCEEDED`
+    3. [Update the file](#/Analyses/patchFile), which marks the upload as `SUCCEEDED`
     """
 
     return sync_detailed(
@@ -117,8 +117,8 @@ async def asyncio(
     client: Client,
     json_body: FileCreate,
 ) -> Optional[Union[File, BadRequestError]]:
-    """Create a file of a supported type. Currently, we support these file extensions: .htm, .html, .shtml
-    (HTML); .jmp; .jpe, .jpeg, .jpg (JPEG); .jrp; and .png.
+    """Create a file of a supported type. Currently, we support these file extensions: .csv; .html;
+    .jmp, .jrn, .jrp (JMP), .jpeg, .jpg (JPEG); .png; and .txt.
 
     A successful file upload requires 3 calls in serial:
     1. [Create a file](#/Analyses/createFile), this endpoint, which returns an S3 `PUT` URL for the 2nd
@@ -128,7 +128,7 @@ async def asyncio(
        ```bash
        curl -H \"x-amz-server-side-encryption: AES256\" -X PUT -T <LOCAL_FILE> -L <S3_PUT_URL>
        ```
-    3. [Update the file](#/Analyses/createFile), which marks the upload as `SUCCEEDED`
+    3. [Update the file](#/Analyses/patchFile), which marks the upload as `SUCCEEDED`
     """
 
     return (
