@@ -35,11 +35,11 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[Union[AsyncTaskLink, BadRequestError]]:
     if response.status_code == 202:
-        response_202 = AsyncTaskLink.from_dict(response.json())
+        response_202 = AsyncTaskLink.from_dict(response.json(), strict=False)
 
         return response_202
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     return None
