@@ -35,11 +35,11 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[Union[RnaOligoHelm, BadRequestError, None]]:
     if response.status_code == 201:
-        response_201 = RnaOligoHelm.from_dict(response.json())
+        response_201 = RnaOligoHelm.from_dict(response.json(), strict=False)
 
         return response_201
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     if response.status_code == 503:
