@@ -34,7 +34,7 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[BadRequestError]:
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     return None
