@@ -36,11 +36,11 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[Union[BadRequestError, NotFoundError]]:
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     if response.status_code == 404:
-        response_404 = NotFoundError.from_dict(response.json())
+        response_404 = NotFoundError.from_dict(response.json(), strict=False)
 
         return response_404
     return None
