@@ -43,15 +43,15 @@ def _parse_response(
     *, response: httpx.Response
 ) -> Optional[Union[CollaborationsPaginatedList, BadRequestError, NotFoundError]]:
     if response.status_code == 200:
-        response_200 = CollaborationsPaginatedList.from_dict(response.json())
+        response_200 = CollaborationsPaginatedList.from_dict(response.json(), strict=False)
 
         return response_200
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     if response.status_code == 404:
-        response_404 = NotFoundError.from_dict(response.json())
+        response_404 = NotFoundError.from_dict(response.json(), strict=False)
 
         return response_404
     return None
