@@ -35,7 +35,7 @@ class AnalysisDatasetIds:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_dataset_ids() -> Union[Unset, List[str]]:
@@ -43,7 +43,12 @@ class AnalysisDatasetIds:
 
             return dataset_ids
 
-        dataset_ids = get_dataset_ids() if "datasetIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            dataset_ids = get_dataset_ids()
+        except KeyError:
+            if strict:
+                raise
+            dataset_ids = cast(Union[Unset, List[str]], UNSET)
 
         analysis_dataset_ids = cls(
             dataset_ids=dataset_ids,
