@@ -2,8 +2,9 @@ from typing import Any, cast, Dict, List, Optional, Type, TypeVar, Union
 
 import attr
 
-from ..extensions import NotPresentError
-from ..models.analysis_step_data import AnalysisStepData
+from ..extensions import NotPresentError, UnknownType
+from ..models.analysis_step_dataset_data import AnalysisStepDatasetData
+from ..models.analysis_step_file_data import AnalysisStepFileData
 from ..models.analysis_step_status import AnalysisStepStatus
 from ..types import UNSET, Unset
 
@@ -15,8 +16,10 @@ class AnalysisStep:
     """  """
 
     _id: Union[Unset, str] = UNSET
-    _input_data: Union[Unset, List[AnalysisStepData]] = UNSET
-    _output_data: Union[Unset, List[AnalysisStepData]] = UNSET
+    _input_data: Union[Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]] = UNSET
+    _output_data: Union[
+        Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]
+    ] = UNSET
     _status: Union[Unset, AnalysisStepStatus] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -35,7 +38,13 @@ class AnalysisStep:
         if not isinstance(self._input_data, Unset):
             input_data = []
             for input_data_item_data in self._input_data:
-                input_data_item = input_data_item_data.to_dict()
+                if isinstance(input_data_item_data, UnknownType):
+                    input_data_item = input_data_item_data.value
+                elif isinstance(input_data_item_data, AnalysisStepFileData):
+                    input_data_item = input_data_item_data.to_dict()
+
+                else:
+                    input_data_item = input_data_item_data.to_dict()
 
                 input_data.append(input_data_item)
 
@@ -43,7 +52,13 @@ class AnalysisStep:
         if not isinstance(self._output_data, Unset):
             output_data = []
             for output_data_item_data in self._output_data:
-                output_data_item = output_data_item_data.to_dict()
+                if isinstance(output_data_item_data, UnknownType):
+                    output_data_item = output_data_item_data.value
+                elif isinstance(output_data_item_data, AnalysisStepFileData):
+                    output_data_item = output_data_item_data.to_dict()
+
+                else:
+                    output_data_item = output_data_item_data.to_dict()
 
                 output_data.append(output_data_item)
 
@@ -66,42 +81,107 @@ class AnalysisStep:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
-        def get_input_data() -> Union[Unset, List[AnalysisStepData]]:
+        def get_input_data() -> Union[
+            Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]
+        ]:
             input_data = []
             _input_data = d.pop("inputData")
             for input_data_item_data in _input_data or []:
-                input_data_item = AnalysisStepData.from_dict(input_data_item_data)
+
+                def _parse_input_data_item(
+                    data: Union[Dict[str, Any]]
+                ) -> Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]:
+                    input_data_item: Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        analysis_step_data = AnalysisStepFileData.from_dict(data, strict=True)
+
+                        return analysis_step_data
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        analysis_step_data = AnalysisStepDatasetData.from_dict(data, strict=True)
+
+                        return analysis_step_data
+                    except:  # noqa: E722
+                        pass
+                    return UnknownType(data)
+
+                input_data_item = _parse_input_data_item(input_data_item_data)
 
                 input_data.append(input_data_item)
 
             return input_data
 
-        input_data = (
-            get_input_data() if "inputData" in d else cast(Union[Unset, List[AnalysisStepData]], UNSET)
-        )
+        try:
+            input_data = get_input_data()
+        except KeyError:
+            if strict:
+                raise
+            input_data = cast(
+                Union[Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]], UNSET
+            )
 
-        def get_output_data() -> Union[Unset, List[AnalysisStepData]]:
+        def get_output_data() -> Union[
+            Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]
+        ]:
             output_data = []
             _output_data = d.pop("outputData")
             for output_data_item_data in _output_data or []:
-                output_data_item = AnalysisStepData.from_dict(output_data_item_data)
+
+                def _parse_output_data_item(
+                    data: Union[Dict[str, Any]]
+                ) -> Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]:
+                    output_data_item: Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        analysis_step_data = AnalysisStepFileData.from_dict(data, strict=True)
+
+                        return analysis_step_data
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        analysis_step_data = AnalysisStepDatasetData.from_dict(data, strict=True)
+
+                        return analysis_step_data
+                    except:  # noqa: E722
+                        pass
+                    return UnknownType(data)
+
+                output_data_item = _parse_output_data_item(output_data_item_data)
 
                 output_data.append(output_data_item)
 
             return output_data
 
-        output_data = (
-            get_output_data() if "outputData" in d else cast(Union[Unset, List[AnalysisStepData]], UNSET)
-        )
+        try:
+            output_data = get_output_data()
+        except KeyError:
+            if strict:
+                raise
+            output_data = cast(
+                Union[Unset, List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]], UNSET
+            )
 
         def get_status() -> Union[Unset, AnalysisStepStatus]:
             status = UNSET
@@ -114,7 +194,12 @@ class AnalysisStep:
 
             return status
 
-        status = get_status() if "status" in d else cast(Union[Unset, AnalysisStepStatus], UNSET)
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(Union[Unset, AnalysisStepStatus], UNSET)
 
         analysis_step = cls(
             id=id,
@@ -160,13 +245,15 @@ class AnalysisStep:
         self._id = UNSET
 
     @property
-    def input_data(self) -> List[AnalysisStepData]:
+    def input_data(self) -> List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]:
         if isinstance(self._input_data, Unset):
             raise NotPresentError(self, "input_data")
         return self._input_data
 
     @input_data.setter
-    def input_data(self, value: List[AnalysisStepData]) -> None:
+    def input_data(
+        self, value: List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]
+    ) -> None:
         self._input_data = value
 
     @input_data.deleter
@@ -174,13 +261,15 @@ class AnalysisStep:
         self._input_data = UNSET
 
     @property
-    def output_data(self) -> List[AnalysisStepData]:
+    def output_data(self) -> List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]:
         if isinstance(self._output_data, Unset):
             raise NotPresentError(self, "output_data")
         return self._output_data
 
     @output_data.setter
-    def output_data(self, value: List[AnalysisStepData]) -> None:
+    def output_data(
+        self, value: List[Union[AnalysisStepFileData, AnalysisStepDatasetData, UnknownType]]
+    ) -> None:
         self._output_data = value
 
     @output_data.deleter
