@@ -43,26 +43,41 @@ class AnalysisStepDataBase:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_is_multi() -> Union[Unset, bool]:
             is_multi = d.pop("isMulti")
             return is_multi
 
-        is_multi = get_is_multi() if "isMulti" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_multi = get_is_multi()
+        except KeyError:
+            if strict:
+                raise
+            is_multi = cast(Union[Unset, bool], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         analysis_step_data_base = cls(
             id=id,
