@@ -32,7 +32,7 @@ class AppConfigItemsArchivalChange:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_item_ids() -> Union[Unset, List[str]]:
@@ -40,7 +40,12 @@ class AppConfigItemsArchivalChange:
 
             return item_ids
 
-        item_ids = get_item_ids() if "itemIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            item_ids = get_item_ids()
+        except KeyError:
+            if strict:
+                raise
+            item_ids = cast(Union[Unset, List[str]], UNSET)
 
         app_config_items_archival_change = cls(
             item_ids=item_ids,
