@@ -90,7 +90,7 @@ class BackTranslate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_aa_sequence_ids() -> List[str]:
@@ -98,32 +98,46 @@ class BackTranslate:
 
             return aa_sequence_ids
 
-        aa_sequence_ids = get_aa_sequence_ids() if "aaSequenceIds" in d else cast(List[str], UNSET)
+        try:
+            aa_sequence_ids = get_aa_sequence_ids()
+        except KeyError:
+            if strict:
+                raise
+            aa_sequence_ids = cast(List[str], UNSET)
 
         def get_folder_id() -> str:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(str, UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(str, UNSET)
 
         def get_avoided_cutsite_enzyme_ids() -> Union[Unset, List[str]]:
             avoided_cutsite_enzyme_ids = cast(List[str], d.pop("avoidedCutsiteEnzymeIds"))
 
             return avoided_cutsite_enzyme_ids
 
-        avoided_cutsite_enzyme_ids = (
-            get_avoided_cutsite_enzyme_ids()
-            if "avoidedCutsiteEnzymeIds" in d
-            else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            avoided_cutsite_enzyme_ids = get_avoided_cutsite_enzyme_ids()
+        except KeyError:
+            if strict:
+                raise
+            avoided_cutsite_enzyme_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_codon_usage_table_id() -> Union[Unset, str]:
             codon_usage_table_id = d.pop("codonUsageTableId")
             return codon_usage_table_id
 
-        codon_usage_table_id = (
-            get_codon_usage_table_id() if "codonUsageTableId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            codon_usage_table_id = get_codon_usage_table_id()
+        except KeyError:
+            if strict:
+                raise
+            codon_usage_table_id = cast(Union[Unset, str], UNSET)
 
         def get_gc_content() -> Union[Unset, BackTranslateGcContent]:
             gc_content = UNSET
@@ -136,53 +150,67 @@ class BackTranslate:
 
             return gc_content
 
-        gc_content = (
-            get_gc_content() if "gcContent" in d else cast(Union[Unset, BackTranslateGcContent], UNSET)
-        )
+        try:
+            gc_content = get_gc_content()
+        except KeyError:
+            if strict:
+                raise
+            gc_content = cast(Union[Unset, BackTranslateGcContent], UNSET)
 
         def get_hairpin_parameters() -> Union[Unset, BackTranslateHairpinParameters]:
-            hairpin_parameters: Union[Unset, BackTranslateHairpinParameters] = UNSET
+            hairpin_parameters: Union[Unset, Union[Unset, BackTranslateHairpinParameters]] = UNSET
             _hairpin_parameters = d.pop("hairpinParameters")
+
             if not isinstance(_hairpin_parameters, Unset):
                 hairpin_parameters = BackTranslateHairpinParameters.from_dict(_hairpin_parameters)
 
             return hairpin_parameters
 
-        hairpin_parameters = (
-            get_hairpin_parameters()
-            if "hairpinParameters" in d
-            else cast(Union[Unset, BackTranslateHairpinParameters], UNSET)
-        )
+        try:
+            hairpin_parameters = get_hairpin_parameters()
+        except KeyError:
+            if strict:
+                raise
+            hairpin_parameters = cast(Union[Unset, BackTranslateHairpinParameters], UNSET)
 
         def get_reduced_patterns() -> Union[Unset, List[ReducedPattern]]:
             reduced_patterns = []
             _reduced_patterns = d.pop("reducedPatterns")
             for reduced_patterns_item_data in _reduced_patterns or []:
-                reduced_patterns_item = ReducedPattern.from_dict(reduced_patterns_item_data)
+                reduced_patterns_item = ReducedPattern.from_dict(reduced_patterns_item_data, strict=False)
 
                 reduced_patterns.append(reduced_patterns_item)
 
             return reduced_patterns
 
-        reduced_patterns = (
-            get_reduced_patterns()
-            if "reducedPatterns" in d
-            else cast(Union[Unset, List[ReducedPattern]], UNSET)
-        )
+        try:
+            reduced_patterns = get_reduced_patterns()
+        except KeyError:
+            if strict:
+                raise
+            reduced_patterns = cast(Union[Unset, List[ReducedPattern]], UNSET)
 
         def get_schema_id() -> Union[Unset, str]:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(Union[Unset, str], UNSET)
 
         def get_should_deplete_uridine() -> Union[Unset, bool]:
             should_deplete_uridine = d.pop("shouldDepleteUridine")
             return should_deplete_uridine
 
-        should_deplete_uridine = (
-            get_should_deplete_uridine() if "shouldDepleteUridine" in d else cast(Union[Unset, bool], UNSET)
-        )
+        try:
+            should_deplete_uridine = get_should_deplete_uridine()
+        except KeyError:
+            if strict:
+                raise
+            should_deplete_uridine = cast(Union[Unset, bool], UNSET)
 
         back_translate = cls(
             aa_sequence_ids=aa_sequence_ids,
