@@ -57,7 +57,7 @@ class BarcodeFormField:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_type() -> Union[Unset, BarcodeFormFieldType]:
@@ -71,31 +71,56 @@ class BarcodeFormField:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, BarcodeFormFieldType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, BarcodeFormFieldType], UNSET)
 
         def get_description() -> Union[Unset, str]:
             description = d.pop("description")
             return description
 
-        description = get_description() if "description" in d else cast(Union[Unset, str], UNSET)
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, str], UNSET)
 
         def get_is_required() -> Union[Unset, bool]:
             is_required = d.pop("isRequired")
             return is_required
 
-        is_required = get_is_required() if "isRequired" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_required = get_is_required()
+        except KeyError:
+            if strict:
+                raise
+            is_required = cast(Union[Unset, bool], UNSET)
 
         def get_key() -> Union[Unset, str]:
             key = d.pop("key")
             return key
 
-        key = get_key() if "key" in d else cast(Union[Unset, str], UNSET)
+        try:
+            key = get_key()
+        except KeyError:
+            if strict:
+                raise
+            key = cast(Union[Unset, str], UNSET)
 
         def get_label() -> Union[Unset, str]:
             label = d.pop("label")
             return label
 
-        label = get_label() if "label" in d else cast(Union[Unset, str], UNSET)
+        try:
+            label = get_label()
+        except KeyError:
+            if strict:
+                raise
+            label = cast(Union[Unset, str], UNSET)
 
         barcode_form_field = cls(
             type=type,
