@@ -76,7 +76,7 @@ class BaseFormDefinitionVersion:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_fields() -> Union[
@@ -120,7 +120,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = StringSelectFormField.from_dict(data)
+                        fields_item = StringSelectFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -128,7 +128,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = FreeFormTextFormField.from_dict(data)
+                        fields_item = FreeFormTextFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -136,7 +136,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = DateSelectionFormField.from_dict(data)
+                        fields_item = DateSelectionFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -144,7 +144,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = EntityLinkFormField.from_dict(data)
+                        fields_item = EntityLinkFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -152,7 +152,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = BarcodeFormField.from_dict(data)
+                        fields_item = BarcodeFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -160,7 +160,7 @@ class BaseFormDefinitionVersion:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        fields_item = NestedFormField.from_dict(data)
+                        fields_item = NestedFormField.from_dict(data, strict=True)
 
                         return fields_item
                     except:  # noqa: E722
@@ -173,10 +173,12 @@ class BaseFormDefinitionVersion:
 
             return fields
 
-        fields = (
-            get_fields()
-            if "fields" in d
-            else cast(
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(
                 Union[
                     Unset,
                     List[
@@ -193,7 +195,6 @@ class BaseFormDefinitionVersion:
                 ],
                 UNSET,
             )
-        )
 
         base_form_definition_version = cls(
             fields=fields,
