@@ -88,20 +88,30 @@ class BenchlingAppUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_description() -> Union[Unset, str]:
             description = d.pop("description")
             return description
 
-        description = get_description() if "description" in d else cast(Union[Unset, str], UNSET)
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_configuration() -> Union[
             Unset,
@@ -147,151 +157,153 @@ class BenchlingAppUpdate:
                     discriminator_value: str = cast(str, data.get("type"))
                     if discriminator_value is not None:
                         if discriminator_value == "aa_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "boolean":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "box":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "box_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "container":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "container_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "custom_entity":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "date":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "datetime":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dna_oligo":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dna_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dropdown":
-                            configuration_item = DropdownDependencyLink.from_dict(data)
+                            configuration_item = DropdownDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entity_schema":
-                            configuration_item = EntitySchemaDependencyLink.from_dict(data)
+                            configuration_item = EntitySchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entry":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entry_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "float":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "folder":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "integer":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "json":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "location":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "location_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "mixture":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "molecule":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "plate":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "plate_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "project":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "registry":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "request_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "result_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "rna_oligo":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "rna_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "run_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "secure_text":
-                            configuration_item = SecureTextConfig.from_dict(data)
+                            configuration_item = SecureTextConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "text":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "workflow_task_schema":
-                            configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data)
+                            configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(
+                                data, strict=False
+                            )
 
                             return configuration_item
                         if discriminator_value == "workflow_task_status":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "worklist":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
 
@@ -299,7 +311,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = SchemaDependencyLink.from_dict(data)
+                        configuration_item = SchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -307,7 +319,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = EntitySchemaDependencyLink.from_dict(data)
+                        configuration_item = EntitySchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -315,7 +327,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data)
+                        configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -323,7 +335,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = DropdownDependencyLink.from_dict(data)
+                        configuration_item = DropdownDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -331,7 +343,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ResourceDependencyLink.from_dict(data)
+                        configuration_item = ResourceDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -339,7 +351,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ScalarConfig.from_dict(data)
+                        configuration_item = ScalarConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -347,7 +359,7 @@ class BenchlingAppUpdate:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = SecureTextConfig.from_dict(data)
+                        configuration_item = SecureTextConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -360,10 +372,12 @@ class BenchlingAppUpdate:
 
             return configuration
 
-        configuration = (
-            get_configuration()
-            if "configuration" in d
-            else cast(
+        try:
+            configuration = get_configuration()
+        except KeyError:
+            if strict:
+                raise
+            configuration = cast(
                 Union[
                     Unset,
                     List[
@@ -381,7 +395,6 @@ class BenchlingAppUpdate:
                 ],
                 UNSET,
             )
-        )
 
         benchling_app_update = cls(
             description=description,
