@@ -51,26 +51,41 @@ class Dataset:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_error_message() -> Union[Unset, None, str]:
             error_message = d.pop("errorMessage")
             return error_message
 
-        error_message = get_error_message() if "errorMessage" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            error_message = get_error_message()
+        except KeyError:
+            if strict:
+                raise
+            error_message = cast(Union[Unset, None, str], UNSET)
 
         def get_upload_status() -> Union[Unset, FileStatusUploadStatus]:
             upload_status = UNSET
@@ -83,9 +98,12 @@ class Dataset:
 
             return upload_status
 
-        upload_status = (
-            get_upload_status() if "uploadStatus" in d else cast(Union[Unset, FileStatusUploadStatus], UNSET)
-        )
+        try:
+            upload_status = get_upload_status()
+        except KeyError:
+            if strict:
+                raise
+            upload_status = cast(Union[Unset, FileStatusUploadStatus], UNSET)
 
         dataset = cls(
             id=id,
@@ -132,6 +150,7 @@ class Dataset:
 
     @property
     def name(self) -> str:
+        """ The user-facing name for this Dataset. """
         if isinstance(self._name, Unset):
             raise NotPresentError(self, "name")
         return self._name
