@@ -107,48 +107,71 @@ class EntryCreateAttachments:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_folder_id() -> str:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(str, UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(str, UNSET)
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
         def get_initial_tables() -> Union[Unset, List[InitialTable]]:
             initial_tables = []
             _initial_tables = d.pop("initialTables")
             for initial_tables_item_data in _initial_tables or []:
-                initial_tables_item = InitialTable.from_dict(initial_tables_item_data)
+                initial_tables_item = InitialTable.from_dict(initial_tables_item_data, strict=False)
 
                 initial_tables.append(initial_tables_item)
 
             return initial_tables
 
-        initial_tables = (
-            get_initial_tables() if "initialTables" in d else cast(Union[Unset, List[InitialTable]], UNSET)
-        )
+        try:
+            initial_tables = get_initial_tables()
+        except KeyError:
+            if strict:
+                raise
+            initial_tables = cast(Union[Unset, List[InitialTable]], UNSET)
 
         def get_attachment_text() -> Union[Unset, None]:
             attachment_text = None
 
             return attachment_text
 
-        attachment_text = get_attachment_text() if "attachmentText" in d else cast(Union[Unset, None], UNSET)
+        try:
+            attachment_text = get_attachment_text()
+        except KeyError:
+            if strict:
+                raise
+            attachment_text = cast(Union[Unset, None], UNSET)
 
         def get_attachments() -> Union[Unset, List[str]]:
             attachments = cast(List[str], d.pop("attachments"))
 
             return attachments
 
-        attachments = get_attachments() if "attachments" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            attachments = get_attachments()
+        except KeyError:
+            if strict:
+                raise
+            attachments = cast(Union[Unset, List[str]], UNSET)
 
         def get_author_ids() -> Union[Unset, str, List[str], UnknownType]:
             def _parse_author_ids(
@@ -173,45 +196,66 @@ class EntryCreateAttachments:
 
             return author_ids
 
-        author_ids = (
-            get_author_ids() if "authorIds" in d else cast(Union[Unset, str, List[str], UnknownType], UNSET)
-        )
+        try:
+            author_ids = get_author_ids()
+        except KeyError:
+            if strict:
+                raise
+            author_ids = cast(Union[Unset, str, List[str], UnknownType], UNSET)
 
         def get_custom_fields() -> Union[Unset, CustomFields]:
-            custom_fields: Union[Unset, CustomFields] = UNSET
+            custom_fields: Union[Unset, Union[Unset, CustomFields]] = UNSET
             _custom_fields = d.pop("customFields")
+
             if not isinstance(_custom_fields, Unset):
                 custom_fields = CustomFields.from_dict(_custom_fields)
 
             return custom_fields
 
-        custom_fields = (
-            get_custom_fields() if "customFields" in d else cast(Union[Unset, CustomFields], UNSET)
-        )
+        try:
+            custom_fields = get_custom_fields()
+        except KeyError:
+            if strict:
+                raise
+            custom_fields = cast(Union[Unset, CustomFields], UNSET)
 
         def get_entry_template_id() -> Union[Unset, str]:
             entry_template_id = d.pop("entryTemplateId")
             return entry_template_id
 
-        entry_template_id = (
-            get_entry_template_id() if "entryTemplateId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            entry_template_id = get_entry_template_id()
+        except KeyError:
+            if strict:
+                raise
+            entry_template_id = cast(Union[Unset, str], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_schema_id() -> Union[Unset, str]:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(Union[Unset, str], UNSET)
 
         entry_create_attachments = cls(
             folder_id=folder_id,
