@@ -40,22 +40,25 @@ class EntryCreateInitialTablesArray:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_initial_tables() -> Union[Unset, List[InitialTable]]:
             initial_tables = []
             _initial_tables = d.pop("initialTables")
             for initial_tables_item_data in _initial_tables or []:
-                initial_tables_item = InitialTable.from_dict(initial_tables_item_data)
+                initial_tables_item = InitialTable.from_dict(initial_tables_item_data, strict=False)
 
                 initial_tables.append(initial_tables_item)
 
             return initial_tables
 
-        initial_tables = (
-            get_initial_tables() if "initialTables" in d else cast(Union[Unset, List[InitialTable]], UNSET)
-        )
+        try:
+            initial_tables = get_initial_tables()
+        except KeyError:
+            if strict:
+                raise
+            initial_tables = cast(Union[Unset, List[InitialTable]], UNSET)
 
         entry_create_initial_tables_array = cls(
             initial_tables=initial_tables,
