@@ -65,32 +65,47 @@ class ExternalFileNotePart:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_external_file_id() -> Union[Unset, str]:
             external_file_id = d.pop("externalFileId")
             return external_file_id
 
-        external_file_id = get_external_file_id() if "externalFileId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            external_file_id = get_external_file_id()
+        except KeyError:
+            if strict:
+                raise
+            external_file_id = cast(Union[Unset, str], UNSET)
 
         def get_links() -> Union[Unset, List[EntryLink]]:
             links = []
             _links = d.pop("links")
             for links_item_data in _links or []:
-                links_item = EntryLink.from_dict(links_item_data)
+                links_item = EntryLink.from_dict(links_item_data, strict=False)
 
                 links.append(links_item)
 
             return links
 
-        links = get_links() if "links" in d else cast(Union[Unset, List[EntryLink]], UNSET)
+        try:
+            links = get_links()
+        except KeyError:
+            if strict:
+                raise
+            links = cast(Union[Unset, List[EntryLink]], UNSET)
 
         def get_text() -> Union[Unset, str]:
             text = d.pop("text")
             return text
 
-        text = get_text() if "text" in d else cast(Union[Unset, str], UNSET)
+        try:
+            text = get_text()
+        except KeyError:
+            if strict:
+                raise
+            text = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, ExternalFileNotePartType]:
             type = UNSET
@@ -103,13 +118,23 @@ class ExternalFileNotePart:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, ExternalFileNotePartType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, ExternalFileNotePartType], UNSET)
 
         def get_indentation() -> Union[Unset, int]:
             indentation = d.pop("indentation")
             return indentation
 
-        indentation = get_indentation() if "indentation" in d else cast(Union[Unset, int], UNSET)
+        try:
+            indentation = get_indentation()
+        except KeyError:
+            if strict:
+                raise
+            indentation = cast(Union[Unset, int], UNSET)
 
         external_file_note_part = cls(
             external_file_id=external_file_id,
@@ -202,7 +227,7 @@ class ExternalFileNotePart:
 
     @property
     def indentation(self) -> int:
-        """All notes have an indentation level - the default is 0 for no indent. For lists, indentation gives notes hierarchy - a bulleted list with children is modeled as one note part with indentation 1 followed by note parts with indentation 2, for example."""
+        """ All notes have an indentation level - the default is 0 for no indent. For lists, indentation gives notes hierarchy - a bulleted list with children is modeled as one note part with indentation 1 followed by note parts with indentation 2, for example. """
         if isinstance(self._indentation, Unset):
             raise NotPresentError(self, "indentation")
         return self._indentation
