@@ -41,14 +41,19 @@ class FileStatus:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_error_message() -> Union[Unset, None, str]:
             error_message = d.pop("errorMessage")
             return error_message
 
-        error_message = get_error_message() if "errorMessage" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            error_message = get_error_message()
+        except KeyError:
+            if strict:
+                raise
+            error_message = cast(Union[Unset, None, str], UNSET)
 
         def get_upload_status() -> Union[Unset, FileStatusUploadStatus]:
             upload_status = UNSET
@@ -61,9 +66,12 @@ class FileStatus:
 
             return upload_status
 
-        upload_status = (
-            get_upload_status() if "uploadStatus" in d else cast(Union[Unset, FileStatusUploadStatus], UNSET)
-        )
+        try:
+            upload_status = get_upload_status()
+        except KeyError:
+            if strict:
+                raise
+            upload_status = cast(Union[Unset, FileStatusUploadStatus], UNSET)
 
         file_status = cls(
             error_message=error_message,
