@@ -41,14 +41,19 @@ class FormFieldValueReference:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_key() -> Union[Unset, str]:
             key = d.pop("key")
             return key
 
-        key = get_key() if "key" in d else cast(Union[Unset, str], UNSET)
+        try:
+            key = get_key()
+        except KeyError:
+            if strict:
+                raise
+            key = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, FormFieldValueReferenceType]:
             type = UNSET
@@ -61,7 +66,12 @@ class FormFieldValueReference:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, FormFieldValueReferenceType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, FormFieldValueReferenceType], UNSET)
 
         form_field_value_reference = cls(
             key=key,
