@@ -100,20 +100,24 @@ class NestedFormField:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_definition() -> Union[Unset, NestedFormDefinition]:
-            definition: Union[Unset, NestedFormDefinition] = UNSET
+            definition: Union[Unset, Union[Unset, NestedFormDefinition]] = UNSET
             _definition = d.pop("definition")
+
             if not isinstance(_definition, Unset):
                 definition = NestedFormDefinition.from_dict(_definition)
 
             return definition
 
-        definition = (
-            get_definition() if "definition" in d else cast(Union[Unset, NestedFormDefinition], UNSET)
-        )
+        try:
+            definition = get_definition()
+        except KeyError:
+            if strict:
+                raise
+            definition = cast(Union[Unset, NestedFormDefinition], UNSET)
 
         def get_instance_providers() -> Union[
             Unset,
@@ -147,7 +151,7 @@ class NestedFormField:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        instance_providers_item = BarcodeScanFormInstanceProvider.from_dict(data)
+                        instance_providers_item = BarcodeScanFormInstanceProvider.from_dict(data, strict=True)
 
                         return instance_providers_item
                     except:  # noqa: E722
@@ -155,7 +159,9 @@ class NestedFormField:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        instance_providers_item = EntitySearchFormInstanceProvider.from_dict(data)
+                        instance_providers_item = EntitySearchFormInstanceProvider.from_dict(
+                            data, strict=True
+                        )
 
                         return instance_providers_item
                     except:  # noqa: E722
@@ -163,7 +169,7 @@ class NestedFormField:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        instance_providers_item = NewBlankFormInstanceProvider.from_dict(data)
+                        instance_providers_item = NewBlankFormInstanceProvider.from_dict(data, strict=True)
 
                         return instance_providers_item
                     except:  # noqa: E722
@@ -176,10 +182,12 @@ class NestedFormField:
 
             return instance_providers
 
-        instance_providers = (
-            get_instance_providers()
-            if "instanceProviders" in d
-            else cast(
+        try:
+            instance_providers = get_instance_providers()
+        except KeyError:
+            if strict:
+                raise
+            instance_providers = cast(
                 Union[
                     Unset,
                     List[
@@ -193,7 +201,6 @@ class NestedFormField:
                 ],
                 UNSET,
             )
-        )
 
         def get_type() -> Union[Unset, NestedFormFieldType]:
             type = UNSET
@@ -206,31 +213,56 @@ class NestedFormField:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, NestedFormFieldType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, NestedFormFieldType], UNSET)
 
         def get_description() -> Union[Unset, str]:
             description = d.pop("description")
             return description
 
-        description = get_description() if "description" in d else cast(Union[Unset, str], UNSET)
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, str], UNSET)
 
         def get_is_required() -> Union[Unset, bool]:
             is_required = d.pop("isRequired")
             return is_required
 
-        is_required = get_is_required() if "isRequired" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_required = get_is_required()
+        except KeyError:
+            if strict:
+                raise
+            is_required = cast(Union[Unset, bool], UNSET)
 
         def get_key() -> Union[Unset, str]:
             key = d.pop("key")
             return key
 
-        key = get_key() if "key" in d else cast(Union[Unset, str], UNSET)
+        try:
+            key = get_key()
+        except KeyError:
+            if strict:
+                raise
+            key = cast(Union[Unset, str], UNSET)
 
         def get_label() -> Union[Unset, str]:
             label = d.pop("label")
             return label
 
-        label = get_label() if "label" in d else cast(Union[Unset, str], UNSET)
+        try:
+            label = get_label()
+        except KeyError:
+            if strict:
+                raise
+            label = cast(Union[Unset, str], UNSET)
 
         nested_form_field = cls(
             definition=definition,
