@@ -3,7 +3,7 @@ from typing import Any, cast, Dict, List, Optional, Type, TypeVar, Union
 import attr
 
 from ..extensions import NotPresentError
-from ..models.schema_base_dependency_field_definitions_item import SchemaBaseDependencyFieldDefinitionsItem
+from ..models.field_definitions_manifest import FieldDefinitionsManifest
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="SchemaBaseDependency")
@@ -14,16 +14,16 @@ class SchemaBaseDependency:
     """  """
 
     _name: str
-    _field_definitions: Union[Unset, List[SchemaBaseDependencyFieldDefinitionsItem]] = UNSET
-    _description: Union[Unset, None, str] = UNSET
+    _field_definitions: Union[Unset, List[FieldDefinitionsManifest]] = UNSET
     _required_config: Union[Unset, bool] = False
+    _description: Union[Unset, None, str] = UNSET
 
     def __repr__(self):
         fields = []
         fields.append("name={}".format(repr(self._name)))
         fields.append("field_definitions={}".format(repr(self._field_definitions)))
-        fields.append("description={}".format(repr(self._description)))
         fields.append("required_config={}".format(repr(self._required_config)))
+        fields.append("description={}".format(repr(self._description)))
         return "SchemaBaseDependency({})".format(", ".join(fields))
 
     def to_dict(self) -> Dict[str, Any]:
@@ -36,8 +36,8 @@ class SchemaBaseDependency:
 
                 field_definitions.append(field_definitions_item)
 
-        description = self._description
         required_config = self._required_config
+        description = self._description
 
         field_dict: Dict[str, Any] = {}
         # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
@@ -45,58 +45,74 @@ class SchemaBaseDependency:
             field_dict["name"] = name
         if field_definitions is not UNSET:
             field_dict["fieldDefinitions"] = field_definitions
-        if description is not UNSET:
-            field_dict["description"] = description
         if required_config is not UNSET:
             field_dict["requiredConfig"] = required_config
+        if description is not UNSET:
+            field_dict["description"] = description
 
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
-        def get_field_definitions() -> Union[Unset, List[SchemaBaseDependencyFieldDefinitionsItem]]:
+        def get_field_definitions() -> Union[Unset, List[FieldDefinitionsManifest]]:
             field_definitions = []
             _field_definitions = d.pop("fieldDefinitions")
             for field_definitions_item_data in _field_definitions or []:
-                field_definitions_item = SchemaBaseDependencyFieldDefinitionsItem.from_dict(
-                    field_definitions_item_data
+                field_definitions_item = FieldDefinitionsManifest.from_dict(
+                    field_definitions_item_data, strict=False
                 )
 
                 field_definitions.append(field_definitions_item)
 
             return field_definitions
 
-        field_definitions = (
-            get_field_definitions()
-            if "fieldDefinitions" in d
-            else cast(Union[Unset, List[SchemaBaseDependencyFieldDefinitionsItem]], UNSET)
-        )
-
-        def get_description() -> Union[Unset, None, str]:
-            description = d.pop("description")
-            return description
-
-        description = get_description() if "description" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            field_definitions = get_field_definitions()
+        except KeyError:
+            if strict:
+                raise
+            field_definitions = cast(Union[Unset, List[FieldDefinitionsManifest]], UNSET)
 
         def get_required_config() -> Union[Unset, bool]:
             required_config = d.pop("requiredConfig")
             return required_config
 
-        required_config = get_required_config() if "requiredConfig" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            required_config = get_required_config()
+        except KeyError:
+            if strict:
+                raise
+            required_config = cast(Union[Unset, bool], UNSET)
+
+        def get_description() -> Union[Unset, None, str]:
+            description = d.pop("description")
+            return description
+
+        try:
+            description = get_description()
+        except KeyError:
+            if strict:
+                raise
+            description = cast(Union[Unset, None, str], UNSET)
 
         schema_base_dependency = cls(
             name=name,
             field_definitions=field_definitions,
-            description=description,
             required_config=required_config,
+            description=description,
         )
 
         return schema_base_dependency
@@ -112,33 +128,19 @@ class SchemaBaseDependency:
         self._name = value
 
     @property
-    def field_definitions(self) -> List[SchemaBaseDependencyFieldDefinitionsItem]:
+    def field_definitions(self) -> List[FieldDefinitionsManifest]:
         if isinstance(self._field_definitions, Unset):
             raise NotPresentError(self, "field_definitions")
         return self._field_definitions
 
     @field_definitions.setter
-    def field_definitions(self, value: List[SchemaBaseDependencyFieldDefinitionsItem]) -> None:
+    def field_definitions(self, value: List[FieldDefinitionsManifest]) -> None:
         self._field_definitions = value
 
     @field_definitions.deleter
     def field_definitions(self) -> None:
         self._field_definitions = UNSET
 
-    @property
-    def description(self) -> Optional[str]:
-        if isinstance(self._description, Unset):
-            raise NotPresentError(self, "description")
-        return self._description
-
-    @description.setter
-    def description(self, value: Optional[str]) -> None:
-        self._description = value
-
-    @description.deleter
-    def description(self) -> None:
-        self._description = UNSET
-
     @property
     def required_config(self) -> bool:
         if isinstance(self._required_config, Unset):
@@ -152,3 +154,17 @@ class SchemaBaseDependency:
     @required_config.deleter
     def required_config(self) -> None:
         self._required_config = UNSET
+
+    @property
+    def description(self) -> Optional[str]:
+        if isinstance(self._description, Unset):
+            raise NotPresentError(self, "description")
+        return self._description
+
+    @description.setter
+    def description(self, value: Optional[str]) -> None:
+        self._description = value
+
+    @description.deleter
+    def description(self) -> None:
+        self._description = UNSET
