@@ -35,20 +35,30 @@ class StringSelectFormFieldOption:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_value() -> Union[Unset, str]:
             value = d.pop("value")
             return value
 
-        value = get_value() if "value" in d else cast(Union[Unset, str], UNSET)
+        try:
+            value = get_value()
+        except KeyError:
+            if strict:
+                raise
+            value = cast(Union[Unset, str], UNSET)
 
         string_select_form_field_option = cls(
             name=name,
