@@ -41,7 +41,7 @@ class WorkflowFlowchartConfigSummary:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_flowchart_config_version_ids() -> Union[Unset, List[str]]:
@@ -49,17 +49,23 @@ class WorkflowFlowchartConfigSummary:
 
             return flowchart_config_version_ids
 
-        flowchart_config_version_ids = (
-            get_flowchart_config_version_ids()
-            if "flowchartConfigVersionIds" in d
-            else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            flowchart_config_version_ids = get_flowchart_config_version_ids()
+        except KeyError:
+            if strict:
+                raise
+            flowchart_config_version_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         workflow_flowchart_config_summary = cls(
             flowchart_config_version_ids=flowchart_config_version_ids,
