@@ -43,30 +43,41 @@ class WorkflowFlowchartEdgeConfig:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_from_node_config_id() -> Union[Unset, str]:
             from_node_config_id = d.pop("fromNodeConfigId")
             return from_node_config_id
 
-        from_node_config_id = (
-            get_from_node_config_id() if "fromNodeConfigId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            from_node_config_id = get_from_node_config_id()
+        except KeyError:
+            if strict:
+                raise
+            from_node_config_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_to_node_config_id() -> Union[Unset, str]:
             to_node_config_id = d.pop("toNodeConfigId")
             return to_node_config_id
 
-        to_node_config_id = (
-            get_to_node_config_id() if "toNodeConfigId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            to_node_config_id = get_to_node_config_id()
+        except KeyError:
+            if strict:
+                raise
+            to_node_config_id = cast(Union[Unset, str], UNSET)
 
         workflow_flowchart_edge_config = cls(
             from_node_config_id=from_node_config_id,
