@@ -48,32 +48,52 @@ class WorkflowNodeTaskGroupSummary:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_node_config_id() -> Union[Unset, str]:
             node_config_id = d.pop("nodeConfigId")
             return node_config_id
 
-        node_config_id = get_node_config_id() if "nodeConfigId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            node_config_id = get_node_config_id()
+        except KeyError:
+            if strict:
+                raise
+            node_config_id = cast(Union[Unset, str], UNSET)
 
         def get_display_id() -> Union[Unset, str]:
             display_id = d.pop("displayId")
             return display_id
 
-        display_id = get_display_id() if "displayId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            display_id = get_display_id()
+        except KeyError:
+            if strict:
+                raise
+            display_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         workflow_node_task_group_summary = cls(
             node_config_id=node_config_id,
