@@ -113,108 +113,163 @@ class AaSequenceUpsert:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
         def get_schema_id() -> str:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(str, UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(str, UNSET)
 
         def get_registry_id() -> str:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(str, UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(str, UNSET)
 
         def get_aliases() -> Union[Unset, List[str]]:
             aliases = cast(List[str], d.pop("aliases"))
 
             return aliases
 
-        aliases = get_aliases() if "aliases" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            aliases = get_aliases()
+        except KeyError:
+            if strict:
+                raise
+            aliases = cast(Union[Unset, List[str]], UNSET)
 
         def get_amino_acids() -> Union[Unset, str]:
             amino_acids = d.pop("aminoAcids")
             return amino_acids
 
-        amino_acids = get_amino_acids() if "aminoAcids" in d else cast(Union[Unset, str], UNSET)
+        try:
+            amino_acids = get_amino_acids()
+        except KeyError:
+            if strict:
+                raise
+            amino_acids = cast(Union[Unset, str], UNSET)
 
         def get_annotations() -> Union[Unset, List[AaAnnotation]]:
             annotations = []
             _annotations = d.pop("annotations")
             for annotations_item_data in _annotations or []:
-                annotations_item = AaAnnotation.from_dict(annotations_item_data)
+                annotations_item = AaAnnotation.from_dict(annotations_item_data, strict=False)
 
                 annotations.append(annotations_item)
 
             return annotations
 
-        annotations = (
-            get_annotations() if "annotations" in d else cast(Union[Unset, List[AaAnnotation]], UNSET)
-        )
+        try:
+            annotations = get_annotations()
+        except KeyError:
+            if strict:
+                raise
+            annotations = cast(Union[Unset, List[AaAnnotation]], UNSET)
 
         def get_author_ids() -> Union[Unset, List[str]]:
             author_ids = cast(List[str], d.pop("authorIds"))
 
             return author_ids
 
-        author_ids = get_author_ids() if "authorIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            author_ids = get_author_ids()
+        except KeyError:
+            if strict:
+                raise
+            author_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_custom_fields() -> Union[Unset, CustomFields]:
-            custom_fields: Union[Unset, CustomFields] = UNSET
+            custom_fields: Union[Unset, Union[Unset, CustomFields]] = UNSET
             _custom_fields = d.pop("customFields")
+
             if not isinstance(_custom_fields, Unset):
                 custom_fields = CustomFields.from_dict(_custom_fields)
 
             return custom_fields
 
-        custom_fields = (
-            get_custom_fields() if "customFields" in d else cast(Union[Unset, CustomFields], UNSET)
-        )
+        try:
+            custom_fields = get_custom_fields()
+        except KeyError:
+            if strict:
+                raise
+            custom_fields = cast(Union[Unset, CustomFields], UNSET)
 
         def get_fields() -> Union[Unset, FieldsWithResolution]:
-            fields: Union[Unset, FieldsWithResolution] = UNSET
+            fields: Union[Unset, Union[Unset, FieldsWithResolution]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = FieldsWithResolution.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, FieldsWithResolution], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, FieldsWithResolution], UNSET)
 
         def get_folder_id() -> Union[Unset, str]:
             folder_id = d.pop("folderId")
             return folder_id
 
-        folder_id = get_folder_id() if "folderId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            folder_id = get_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            folder_id = cast(Union[Unset, str], UNSET)
 
         def get_entity_registry_id() -> Union[Unset, str]:
             entity_registry_id = d.pop("entityRegistryId")
             return entity_registry_id
 
-        entity_registry_id = (
-            get_entity_registry_id() if "entityRegistryId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            entity_registry_id = get_entity_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            entity_registry_id = cast(Union[Unset, str], UNSET)
 
         def get_archive_record() -> Union[Unset, ArchiveRecordSet]:
-            archive_record: Union[Unset, ArchiveRecordSet] = UNSET
+            archive_record: Union[Unset, Union[Unset, ArchiveRecordSet]] = UNSET
             _archive_record = d.pop("archiveRecord")
+
             if not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecordSet.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, ArchiveRecordSet], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, ArchiveRecordSet], UNSET)
 
         aa_sequence_upsert = cls(
             name=name,
