@@ -64,14 +64,19 @@ class AaSequencesMatchBases:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_amino_acids() -> str:
             amino_acids = d.pop("aminoAcids")
             return amino_acids
 
-        amino_acids = get_amino_acids() if "aminoAcids" in d else cast(str, UNSET)
+        try:
+            amino_acids = get_amino_acids()
+        except KeyError:
+            if strict:
+                raise
+            amino_acids = cast(str, UNSET)
 
         def get_archive_reason() -> Union[Unset, AaSequencesMatchBasesArchiveReason]:
             archive_reason = UNSET
@@ -84,29 +89,45 @@ class AaSequencesMatchBases:
 
             return archive_reason
 
-        archive_reason = (
-            get_archive_reason()
-            if "archiveReason" in d
-            else cast(Union[Unset, AaSequencesMatchBasesArchiveReason], UNSET)
-        )
+        try:
+            archive_reason = get_archive_reason()
+        except KeyError:
+            if strict:
+                raise
+            archive_reason = cast(Union[Unset, AaSequencesMatchBasesArchiveReason], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         def get_page_size() -> Union[Unset, int]:
             page_size = d.pop("pageSize")
             return page_size
 
-        page_size = get_page_size() if "pageSize" in d else cast(Union[Unset, int], UNSET)
+        try:
+            page_size = get_page_size()
+        except KeyError:
+            if strict:
+                raise
+            page_size = cast(Union[Unset, int], UNSET)
 
         def get_registry_id() -> Union[Unset, None, str]:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(Union[Unset, None, str], UNSET)
 
         def get_sort() -> Union[Unset, AaSequencesMatchBasesSort]:
             sort = UNSET
@@ -119,7 +140,12 @@ class AaSequencesMatchBases:
 
             return sort
 
-        sort = get_sort() if "sort" in d else cast(Union[Unset, AaSequencesMatchBasesSort], UNSET)
+        try:
+            sort = get_sort()
+        except KeyError:
+            if strict:
+                raise
+            sort = cast(Union[Unset, AaSequencesMatchBasesSort], UNSET)
 
         aa_sequences_match_bases = cls(
             amino_acids=amino_acids,
