@@ -38,20 +38,30 @@ class BaseNotePart:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_indentation() -> Union[Unset, int]:
             indentation = d.pop("indentation")
             return indentation
 
-        indentation = get_indentation() if "indentation" in d else cast(Union[Unset, int], UNSET)
+        try:
+            indentation = get_indentation()
+        except KeyError:
+            if strict:
+                raise
+            indentation = cast(Union[Unset, int], UNSET)
 
         def get_type() -> Union[Unset, str]:
             type = d.pop("type")
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, str], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, str], UNSET)
 
         base_note_part = cls(
             indentation=indentation,
