@@ -98,32 +98,52 @@ class BenchlingAppConfiguration:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_api_url() -> Union[Unset, str]:
             api_url = d.pop("apiUrl")
             return api_url
 
-        api_url = get_api_url() if "apiUrl" in d else cast(Union[Unset, str], UNSET)
+        try:
+            api_url = get_api_url()
+        except KeyError:
+            if strict:
+                raise
+            api_url = cast(Union[Unset, str], UNSET)
 
         def get_app_id() -> Union[Unset, str]:
             app_id = d.pop("appId")
             return app_id
 
-        app_id = get_app_id() if "appId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            app_id = get_app_id()
+        except KeyError:
+            if strict:
+                raise
+            app_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_modified_at() -> Union[Unset, str]:
             modified_at = d.pop("modifiedAt")
             return modified_at
 
-        modified_at = get_modified_at() if "modifiedAt" in d else cast(Union[Unset, str], UNSET)
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, str], UNSET)
 
         def get_configuration() -> Union[
             Unset,
@@ -169,151 +189,153 @@ class BenchlingAppConfiguration:
                     discriminator_value: str = cast(str, data.get("type"))
                     if discriminator_value is not None:
                         if discriminator_value == "aa_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "boolean":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "box":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "box_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "container":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "container_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "custom_entity":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "date":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "datetime":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dna_oligo":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dna_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "dropdown":
-                            configuration_item = DropdownDependencyLink.from_dict(data)
+                            configuration_item = DropdownDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entity_schema":
-                            configuration_item = EntitySchemaDependencyLink.from_dict(data)
+                            configuration_item = EntitySchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entry":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "entry_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "float":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "folder":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "integer":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "json":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "location":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "location_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "mixture":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "molecule":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "plate":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "plate_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "project":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "registry":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "request_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "result_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "rna_oligo":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "rna_sequence":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "run_schema":
-                            configuration_item = SchemaDependencyLink.from_dict(data)
+                            configuration_item = SchemaDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "secure_text":
-                            configuration_item = SecureTextConfig.from_dict(data)
+                            configuration_item = SecureTextConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "text":
-                            configuration_item = ScalarConfig.from_dict(data)
+                            configuration_item = ScalarConfig.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "workflow_task_schema":
-                            configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data)
+                            configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(
+                                data, strict=False
+                            )
 
                             return configuration_item
                         if discriminator_value == "workflow_task_status":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
                         if discriminator_value == "worklist":
-                            configuration_item = ResourceDependencyLink.from_dict(data)
+                            configuration_item = ResourceDependencyLink.from_dict(data, strict=False)
 
                             return configuration_item
 
@@ -321,7 +343,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = SchemaDependencyLink.from_dict(data)
+                        configuration_item = SchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -329,7 +351,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = EntitySchemaDependencyLink.from_dict(data)
+                        configuration_item = EntitySchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -337,7 +359,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data)
+                        configuration_item = WorkflowTaskSchemaDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -345,7 +367,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = DropdownDependencyLink.from_dict(data)
+                        configuration_item = DropdownDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -353,7 +375,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ResourceDependencyLink.from_dict(data)
+                        configuration_item = ResourceDependencyLink.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -361,7 +383,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = ScalarConfig.from_dict(data)
+                        configuration_item = ScalarConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -369,7 +391,7 @@ class BenchlingAppConfiguration:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        configuration_item = SecureTextConfig.from_dict(data)
+                        configuration_item = SecureTextConfig.from_dict(data, strict=True)
 
                         return configuration_item
                     except:  # noqa: E722
@@ -382,10 +404,12 @@ class BenchlingAppConfiguration:
 
             return configuration
 
-        configuration = (
-            get_configuration()
-            if "configuration" in d
-            else cast(
+        try:
+            configuration = get_configuration()
+        except KeyError:
+            if strict:
+                raise
+            configuration = cast(
                 Union[
                     Unset,
                     List[
@@ -403,7 +427,6 @@ class BenchlingAppConfiguration:
                 ],
                 UNSET,
             )
-        )
 
         benchling_app_configuration = cls(
             api_url=api_url,
