@@ -35,20 +35,25 @@ class DnaOligosBulkUpsertRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_dna_oligos() -> List[OligoBulkUpsertRequest]:
             dna_oligos = []
             _dna_oligos = d.pop("dnaOligos")
             for dna_oligos_item_data in _dna_oligos:
-                dna_oligos_item = OligoBulkUpsertRequest.from_dict(dna_oligos_item_data)
+                dna_oligos_item = OligoBulkUpsertRequest.from_dict(dna_oligos_item_data, strict=False)
 
                 dna_oligos.append(dna_oligos_item)
 
             return dna_oligos
 
-        dna_oligos = get_dna_oligos() if "dnaOligos" in d else cast(List[OligoBulkUpsertRequest], UNSET)
+        try:
+            dna_oligos = get_dna_oligos()
+        except KeyError:
+            if strict:
+                raise
+            dna_oligos = cast(List[OligoBulkUpsertRequest], UNSET)
 
         dna_oligos_bulk_upsert_request = cls(
             dna_oligos=dna_oligos,
