@@ -101,100 +101,116 @@ class EntitiesBulkUpsertRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_aa_sequences() -> Union[Unset, List[AaSequenceBulkUpsertRequest]]:
             aa_sequences = []
             _aa_sequences = d.pop("aaSequences")
             for aa_sequences_item_data in _aa_sequences or []:
-                aa_sequences_item = AaSequenceBulkUpsertRequest.from_dict(aa_sequences_item_data)
+                aa_sequences_item = AaSequenceBulkUpsertRequest.from_dict(
+                    aa_sequences_item_data, strict=False
+                )
 
                 aa_sequences.append(aa_sequences_item)
 
             return aa_sequences
 
-        aa_sequences = (
-            get_aa_sequences()
-            if "aaSequences" in d
-            else cast(Union[Unset, List[AaSequenceBulkUpsertRequest]], UNSET)
-        )
+        try:
+            aa_sequences = get_aa_sequences()
+        except KeyError:
+            if strict:
+                raise
+            aa_sequences = cast(Union[Unset, List[AaSequenceBulkUpsertRequest]], UNSET)
 
         def get_custom_entities() -> Union[Unset, List[CustomEntityBulkUpsertRequest]]:
             custom_entities = []
             _custom_entities = d.pop("customEntities")
             for custom_entities_item_data in _custom_entities or []:
-                custom_entities_item = CustomEntityBulkUpsertRequest.from_dict(custom_entities_item_data)
+                custom_entities_item = CustomEntityBulkUpsertRequest.from_dict(
+                    custom_entities_item_data, strict=False
+                )
 
                 custom_entities.append(custom_entities_item)
 
             return custom_entities
 
-        custom_entities = (
-            get_custom_entities()
-            if "customEntities" in d
-            else cast(Union[Unset, List[CustomEntityBulkUpsertRequest]], UNSET)
-        )
+        try:
+            custom_entities = get_custom_entities()
+        except KeyError:
+            if strict:
+                raise
+            custom_entities = cast(Union[Unset, List[CustomEntityBulkUpsertRequest]], UNSET)
 
         def get_dna_oligos() -> Union[Unset, List[OligoBulkUpsertRequest]]:
             dna_oligos = []
             _dna_oligos = d.pop("dnaOligos")
             for dna_oligos_item_data in _dna_oligos or []:
-                dna_oligos_item = OligoBulkUpsertRequest.from_dict(dna_oligos_item_data)
+                dna_oligos_item = OligoBulkUpsertRequest.from_dict(dna_oligos_item_data, strict=False)
 
                 dna_oligos.append(dna_oligos_item)
 
             return dna_oligos
 
-        dna_oligos = (
-            get_dna_oligos() if "dnaOligos" in d else cast(Union[Unset, List[OligoBulkUpsertRequest]], UNSET)
-        )
+        try:
+            dna_oligos = get_dna_oligos()
+        except KeyError:
+            if strict:
+                raise
+            dna_oligos = cast(Union[Unset, List[OligoBulkUpsertRequest]], UNSET)
 
         def get_dna_sequences() -> Union[Unset, List[DnaSequenceBulkUpsertRequest]]:
             dna_sequences = []
             _dna_sequences = d.pop("dnaSequences")
             for dna_sequences_item_data in _dna_sequences or []:
-                dna_sequences_item = DnaSequenceBulkUpsertRequest.from_dict(dna_sequences_item_data)
+                dna_sequences_item = DnaSequenceBulkUpsertRequest.from_dict(
+                    dna_sequences_item_data, strict=False
+                )
 
                 dna_sequences.append(dna_sequences_item)
 
             return dna_sequences
 
-        dna_sequences = (
-            get_dna_sequences()
-            if "dnaSequences" in d
-            else cast(Union[Unset, List[DnaSequenceBulkUpsertRequest]], UNSET)
-        )
+        try:
+            dna_sequences = get_dna_sequences()
+        except KeyError:
+            if strict:
+                raise
+            dna_sequences = cast(Union[Unset, List[DnaSequenceBulkUpsertRequest]], UNSET)
 
         def get_molecules() -> Union[Unset, List[MoleculeBulkUpsertRequest]]:
             molecules = []
             _molecules = d.pop("molecules")
             for molecules_item_data in _molecules or []:
-                molecules_item = MoleculeBulkUpsertRequest.from_dict(molecules_item_data)
+                molecules_item = MoleculeBulkUpsertRequest.from_dict(molecules_item_data, strict=False)
 
                 molecules.append(molecules_item)
 
             return molecules
 
-        molecules = (
-            get_molecules()
-            if "molecules" in d
-            else cast(Union[Unset, List[MoleculeBulkUpsertRequest]], UNSET)
-        )
+        try:
+            molecules = get_molecules()
+        except KeyError:
+            if strict:
+                raise
+            molecules = cast(Union[Unset, List[MoleculeBulkUpsertRequest]], UNSET)
 
         def get_rna_oligos() -> Union[Unset, List[OligoBulkUpsertRequest]]:
             rna_oligos = []
             _rna_oligos = d.pop("rnaOligos")
             for rna_oligos_item_data in _rna_oligos or []:
-                rna_oligos_item = OligoBulkUpsertRequest.from_dict(rna_oligos_item_data)
+                rna_oligos_item = OligoBulkUpsertRequest.from_dict(rna_oligos_item_data, strict=False)
 
                 rna_oligos.append(rna_oligos_item)
 
             return rna_oligos
 
-        rna_oligos = (
-            get_rna_oligos() if "rnaOligos" in d else cast(Union[Unset, List[OligoBulkUpsertRequest]], UNSET)
-        )
+        try:
+            rna_oligos = get_rna_oligos()
+        except KeyError:
+            if strict:
+                raise
+            rna_oligos = cast(Union[Unset, List[OligoBulkUpsertRequest]], UNSET)
 
         entities_bulk_upsert_request = cls(
             aa_sequences=aa_sequences,
