@@ -60,48 +60,73 @@ class EntityUpsertBaseRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
         def get_registry_id() -> str:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(str, UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(str, UNSET)
 
         def get_schema_id() -> str:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(str, UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(str, UNSET)
 
         def get_archive_record() -> Union[Unset, ArchiveRecordSet]:
-            archive_record: Union[Unset, ArchiveRecordSet] = UNSET
+            archive_record: Union[Unset, Union[Unset, ArchiveRecordSet]] = UNSET
             _archive_record = d.pop("archiveRecord")
+
             if not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecordSet.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, ArchiveRecordSet], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, ArchiveRecordSet], UNSET)
 
         def get_fields() -> Union[Unset, FieldsWithResolution]:
-            fields: Union[Unset, FieldsWithResolution] = UNSET
+            fields: Union[Unset, Union[Unset, FieldsWithResolution]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = FieldsWithResolution.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, FieldsWithResolution], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, FieldsWithResolution], UNSET)
 
         entity_upsert_base_request = cls(
             name=name,
