@@ -45,7 +45,7 @@ class MemberCollaborator:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_role() -> MemberCollaboratorRole:
@@ -57,19 +57,34 @@ class MemberCollaborator:
 
             return role
 
-        role = get_role() if "role" in d else cast(MemberCollaboratorRole, UNSET)
+        try:
+            role = get_role()
+        except KeyError:
+            if strict:
+                raise
+            role = cast(MemberCollaboratorRole, UNSET)
 
         def get_access_policy_id() -> str:
             access_policy_id = d.pop("accessPolicyId")
             return access_policy_id
 
-        access_policy_id = get_access_policy_id() if "accessPolicyId" in d else cast(str, UNSET)
+        try:
+            access_policy_id = get_access_policy_id()
+        except KeyError:
+            if strict:
+                raise
+            access_policy_id = cast(str, UNSET)
 
         def get_collaborator_id() -> str:
             collaborator_id = d.pop("collaboratorId")
             return collaborator_id
 
-        collaborator_id = get_collaborator_id() if "collaboratorId" in d else cast(str, UNSET)
+        try:
+            collaborator_id = get_collaborator_id()
+        except KeyError:
+            if strict:
+                raise
+            collaborator_id = cast(str, UNSET)
 
         member_collaborator = cls(
             role=role,
