@@ -65,14 +65,19 @@ class PlateCreationTableNotePart:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_plate_schema_id() -> Union[Unset, str]:
             plate_schema_id = d.pop("plateSchemaId")
             return plate_schema_id
 
-        plate_schema_id = get_plate_schema_id() if "plateSchemaId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            plate_schema_id = get_plate_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            plate_schema_id = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, PlateCreationTableNotePartType]:
             type = UNSET
@@ -85,33 +90,51 @@ class PlateCreationTableNotePart:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, PlateCreationTableNotePartType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, PlateCreationTableNotePartType], UNSET)
 
         def get_api_id() -> Union[Unset, str]:
             api_id = d.pop("apiId")
             return api_id
 
-        api_id = get_api_id() if "apiId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            api_id = get_api_id()
+        except KeyError:
+            if strict:
+                raise
+            api_id = cast(Union[Unset, str], UNSET)
 
         def get_columns() -> Union[Unset, List[StructuredTableColumnInfo]]:
             columns = []
             _columns = d.pop("columns")
             for columns_item_data in _columns or []:
-                columns_item = StructuredTableColumnInfo.from_dict(columns_item_data)
+                columns_item = StructuredTableColumnInfo.from_dict(columns_item_data, strict=False)
 
                 columns.append(columns_item)
 
             return columns
 
-        columns = (
-            get_columns() if "columns" in d else cast(Union[Unset, List[StructuredTableColumnInfo]], UNSET)
-        )
+        try:
+            columns = get_columns()
+        except KeyError:
+            if strict:
+                raise
+            columns = cast(Union[Unset, List[StructuredTableColumnInfo]], UNSET)
 
         def get_indentation() -> Union[Unset, int]:
             indentation = d.pop("indentation")
             return indentation
 
-        indentation = get_indentation() if "indentation" in d else cast(Union[Unset, int], UNSET)
+        try:
+            indentation = get_indentation()
+        except KeyError:
+            if strict:
+                raise
+            indentation = cast(Union[Unset, int], UNSET)
 
         plate_creation_table_note_part = cls(
             plate_schema_id=plate_schema_id,
