@@ -69,36 +69,52 @@ class TableNotePart:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_links() -> Union[Unset, List[EntryLink]]:
             links = []
             _links = d.pop("links")
             for links_item_data in _links or []:
-                links_item = EntryLink.from_dict(links_item_data)
+                links_item = EntryLink.from_dict(links_item_data, strict=False)
 
                 links.append(links_item)
 
             return links
 
-        links = get_links() if "links" in d else cast(Union[Unset, List[EntryLink]], UNSET)
+        try:
+            links = get_links()
+        except KeyError:
+            if strict:
+                raise
+            links = cast(Union[Unset, List[EntryLink]], UNSET)
 
         def get_table() -> Union[Unset, EntryTable]:
-            table: Union[Unset, EntryTable] = UNSET
+            table: Union[Unset, Union[Unset, EntryTable]] = UNSET
             _table = d.pop("table")
+
             if not isinstance(_table, Unset):
                 table = EntryTable.from_dict(_table)
 
             return table
 
-        table = get_table() if "table" in d else cast(Union[Unset, EntryTable], UNSET)
+        try:
+            table = get_table()
+        except KeyError:
+            if strict:
+                raise
+            table = cast(Union[Unset, EntryTable], UNSET)
 
         def get_text() -> Union[Unset, str]:
             text = d.pop("text")
             return text
 
-        text = get_text() if "text" in d else cast(Union[Unset, str], UNSET)
+        try:
+            text = get_text()
+        except KeyError:
+            if strict:
+                raise
+            text = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, TableNotePartType]:
             type = UNSET
@@ -111,13 +127,23 @@ class TableNotePart:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, TableNotePartType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, TableNotePartType], UNSET)
 
         def get_indentation() -> Union[Unset, int]:
             indentation = d.pop("indentation")
             return indentation
 
-        indentation = get_indentation() if "indentation" in d else cast(Union[Unset, int], UNSET)
+        try:
+            indentation = get_indentation()
+        except KeyError:
+            if strict:
+                raise
+            indentation = cast(Union[Unset, int], UNSET)
 
         table_note_part = cls(
             links=links,
