@@ -88,14 +88,19 @@ class Worklist:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_api_url() -> Union[Unset, str]:
             api_url = d.pop("apiURL")
             return api_url
 
-        api_url = get_api_url() if "apiURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            api_url = get_api_url()
+        except KeyError:
+            if strict:
+                raise
+            api_url = cast(Union[Unset, str], UNSET)
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
             created_at: Union[Unset, datetime.datetime] = UNSET
@@ -105,23 +110,39 @@ class Worklist:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_creator() -> Union[Unset, WorklistCreator]:
-            creator: Union[Unset, WorklistCreator] = UNSET
+            creator: Union[Unset, Union[Unset, WorklistCreator]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = WorklistCreator.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, WorklistCreator], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, WorklistCreator], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_modified_at() -> Union[Unset, datetime.datetime]:
             modified_at: Union[Unset, datetime.datetime] = UNSET
@@ -131,13 +152,23 @@ class Worklist:
 
             return modified_at
 
-        modified_at = get_modified_at() if "modifiedAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, WorklistType]:
             type = UNSET
@@ -150,23 +181,29 @@ class Worklist:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, WorklistType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, WorklistType], UNSET)
 
         def get_worklist_items() -> Union[Unset, List[WorklistItemSummary]]:
             worklist_items = []
             _worklist_items = d.pop("worklistItems")
             for worklist_items_item_data in _worklist_items or []:
-                worklist_items_item = WorklistItemSummary.from_dict(worklist_items_item_data)
+                worklist_items_item = WorklistItemSummary.from_dict(worklist_items_item_data, strict=False)
 
                 worklist_items.append(worklist_items_item)
 
             return worklist_items
 
-        worklist_items = (
-            get_worklist_items()
-            if "worklistItems" in d
-            else cast(Union[Unset, List[WorklistItemSummary]], UNSET)
-        )
+        try:
+            worklist_items = get_worklist_items()
+        except KeyError:
+            if strict:
+                raise
+            worklist_items = cast(Union[Unset, List[WorklistItemSummary]], UNSET)
 
         worklist = cls(
             api_url=api_url,
