@@ -2,8 +2,9 @@ from typing import Any, cast, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..extensions import NotPresentError
-from ..models.collaboration_create import CollaborationCreate
+from ..extensions import NotPresentError, UnknownType
+from ..models.member_collaborator import MemberCollaborator
+from ..models.principal_collaborator import PrincipalCollaborator
 from ..models.worklist_type import WorklistType
 from ..types import UNSET, Unset
 
@@ -16,7 +17,7 @@ class WorklistCreate:
 
     _name: str
     _type: WorklistType
-    _collaborations: Union[Unset, List[CollaborationCreate]] = UNSET
+    _collaborations: Union[Unset, List[Union[PrincipalCollaborator, MemberCollaborator, UnknownType]]] = UNSET
     _worklist_item_ids: Union[Unset, List[str]] = UNSET
 
     def __repr__(self):
@@ -35,7 +36,13 @@ class WorklistCreate:
         if not isinstance(self._collaborations, Unset):
             collaborations = []
             for collaborations_item_data in self._collaborations:
-                collaborations_item = collaborations_item_data.to_dict()
+                if isinstance(collaborations_item_data, UnknownType):
+                    collaborations_item = collaborations_item_data.value
+                elif isinstance(collaborations_item_data, PrincipalCollaborator):
+                    collaborations_item = collaborations_item_data.to_dict()
+
+                else:
+                    collaborations_item = collaborations_item_data.to_dict()
 
                 collaborations.append(collaborations_item)
 
@@ -57,14 +64,19 @@ class WorklistCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> str:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(str, UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(str, UNSET)
 
         def get_type() -> WorklistType:
             _type = d.pop("type")
@@ -75,32 +87,68 @@ class WorklistCreate:
 
             return type
 
-        type = get_type() if "type" in d else cast(WorklistType, UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(WorklistType, UNSET)
 
-        def get_collaborations() -> Union[Unset, List[CollaborationCreate]]:
+        def get_collaborations() -> Union[
+            Unset, List[Union[PrincipalCollaborator, MemberCollaborator, UnknownType]]
+        ]:
             collaborations = []
             _collaborations = d.pop("collaborations")
             for collaborations_item_data in _collaborations or []:
-                collaborations_item = CollaborationCreate.from_dict(collaborations_item_data)
+
+                def _parse_collaborations_item(
+                    data: Union[Dict[str, Any]]
+                ) -> Union[PrincipalCollaborator, MemberCollaborator, UnknownType]:
+                    collaborations_item: Union[PrincipalCollaborator, MemberCollaborator, UnknownType]
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        collaboration_create = PrincipalCollaborator.from_dict(data, strict=True)
+
+                        return collaboration_create
+                    except:  # noqa: E722
+                        pass
+                    try:
+                        if not isinstance(data, dict):
+                            raise TypeError()
+                        collaboration_create = MemberCollaborator.from_dict(data, strict=True)
+
+                        return collaboration_create
+                    except:  # noqa: E722
+                        pass
+                    return UnknownType(data)
+
+                collaborations_item = _parse_collaborations_item(collaborations_item_data)
 
                 collaborations.append(collaborations_item)
 
             return collaborations
 
-        collaborations = (
-            get_collaborations()
-            if "collaborations" in d
-            else cast(Union[Unset, List[CollaborationCreate]], UNSET)
-        )
+        try:
+            collaborations = get_collaborations()
+        except KeyError:
+            if strict:
+                raise
+            collaborations = cast(
+                Union[Unset, List[Union[PrincipalCollaborator, MemberCollaborator, UnknownType]]], UNSET
+            )
 
         def get_worklist_item_ids() -> Union[Unset, List[str]]:
             worklist_item_ids = cast(List[str], d.pop("worklistItemIds"))
 
             return worklist_item_ids
 
-        worklist_item_ids = (
-            get_worklist_item_ids() if "worklistItemIds" in d else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            worklist_item_ids = get_worklist_item_ids()
+        except KeyError:
+            if strict:
+                raise
+            worklist_item_ids = cast(Union[Unset, List[str]], UNSET)
 
         worklist_create = cls(
             name=name,
@@ -134,13 +182,15 @@ class WorklistCreate:
         self._type = value
 
     @property
-    def collaborations(self) -> List[CollaborationCreate]:
+    def collaborations(self) -> List[Union[PrincipalCollaborator, MemberCollaborator, UnknownType]]:
         if isinstance(self._collaborations, Unset):
             raise NotPresentError(self, "collaborations")
         return self._collaborations
 
     @collaborations.setter
-    def collaborations(self, value: List[CollaborationCreate]) -> None:
+    def collaborations(
+        self, value: List[Union[PrincipalCollaborator, MemberCollaborator, UnknownType]]
+    ) -> None:
         self._collaborations = value
 
     @collaborations.deleter
