@@ -16,12 +16,8 @@ def _get_kwargs(
     modified_at: Union[Unset, str] = UNSET,
     name: Union[Unset, str] = UNSET,
     template_collection_id: Union[Unset, str] = UNSET,
-    mentions: Union[Unset, str] = UNSET,
     ids: Union[Unset, str] = UNSET,
     schema_id: Union[Unset, str] = UNSET,
-    namesany_of: Union[Unset, str] = UNSET,
-    namesany_ofcase_sensitive: Union[Unset, str] = UNSET,
-    creator_ids: Union[Unset, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/entry-templates".format(client.base_url)
 
@@ -42,18 +38,10 @@ def _get_kwargs(
         params["name"] = name
     if not isinstance(template_collection_id, Unset) and template_collection_id is not None:
         params["templateCollectionId"] = template_collection_id
-    if not isinstance(mentions, Unset) and mentions is not None:
-        params["mentions"] = mentions
     if not isinstance(ids, Unset) and ids is not None:
         params["ids"] = ids
     if not isinstance(schema_id, Unset) and schema_id is not None:
         params["schemaId"] = schema_id
-    if not isinstance(namesany_of, Unset) and namesany_of is not None:
-        params["names.anyOf"] = namesany_of
-    if not isinstance(namesany_ofcase_sensitive, Unset) and namesany_ofcase_sensitive is not None:
-        params["names.anyOf.caseSensitive"] = namesany_ofcase_sensitive
-    if not isinstance(creator_ids, Unset) and creator_ids is not None:
-        params["creatorIds"] = creator_ids
 
     return {
         "url": url,
@@ -68,11 +56,11 @@ def _parse_response(
     *, response: httpx.Response
 ) -> Optional[Union[EntryTemplatesPaginatedList, BadRequestError]]:
     if response.status_code == 200:
-        response_200 = EntryTemplatesPaginatedList.from_dict(response.json())
+        response_200 = EntryTemplatesPaginatedList.from_dict(response.json(), strict=False)
 
         return response_200
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     return None
@@ -97,12 +85,8 @@ def sync_detailed(
     modified_at: Union[Unset, str] = UNSET,
     name: Union[Unset, str] = UNSET,
     template_collection_id: Union[Unset, str] = UNSET,
-    mentions: Union[Unset, str] = UNSET,
     ids: Union[Unset, str] = UNSET,
     schema_id: Union[Unset, str] = UNSET,
-    namesany_of: Union[Unset, str] = UNSET,
-    namesany_ofcase_sensitive: Union[Unset, str] = UNSET,
-    creator_ids: Union[Unset, str] = UNSET,
 ) -> Response[Union[EntryTemplatesPaginatedList, BadRequestError]]:
     kwargs = _get_kwargs(
         client=client,
@@ -111,12 +95,8 @@ def sync_detailed(
         modified_at=modified_at,
         name=name,
         template_collection_id=template_collection_id,
-        mentions=mentions,
         ids=ids,
         schema_id=schema_id,
-        namesany_of=namesany_of,
-        namesany_ofcase_sensitive=namesany_ofcase_sensitive,
-        creator_ids=creator_ids,
     )
 
     response = client.httpx_client.get(
@@ -134,12 +114,8 @@ def sync(
     modified_at: Union[Unset, str] = UNSET,
     name: Union[Unset, str] = UNSET,
     template_collection_id: Union[Unset, str] = UNSET,
-    mentions: Union[Unset, str] = UNSET,
     ids: Union[Unset, str] = UNSET,
     schema_id: Union[Unset, str] = UNSET,
-    namesany_of: Union[Unset, str] = UNSET,
-    namesany_ofcase_sensitive: Union[Unset, str] = UNSET,
-    creator_ids: Union[Unset, str] = UNSET,
 ) -> Optional[Union[EntryTemplatesPaginatedList, BadRequestError]]:
     """ List entry templates """
 
@@ -150,12 +126,8 @@ def sync(
         modified_at=modified_at,
         name=name,
         template_collection_id=template_collection_id,
-        mentions=mentions,
         ids=ids,
         schema_id=schema_id,
-        namesany_of=namesany_of,
-        namesany_ofcase_sensitive=namesany_ofcase_sensitive,
-        creator_ids=creator_ids,
     ).parsed
 
 
@@ -167,12 +139,8 @@ async def asyncio_detailed(
     modified_at: Union[Unset, str] = UNSET,
     name: Union[Unset, str] = UNSET,
     template_collection_id: Union[Unset, str] = UNSET,
-    mentions: Union[Unset, str] = UNSET,
     ids: Union[Unset, str] = UNSET,
     schema_id: Union[Unset, str] = UNSET,
-    namesany_of: Union[Unset, str] = UNSET,
-    namesany_ofcase_sensitive: Union[Unset, str] = UNSET,
-    creator_ids: Union[Unset, str] = UNSET,
 ) -> Response[Union[EntryTemplatesPaginatedList, BadRequestError]]:
     kwargs = _get_kwargs(
         client=client,
@@ -181,12 +149,8 @@ async def asyncio_detailed(
         modified_at=modified_at,
         name=name,
         template_collection_id=template_collection_id,
-        mentions=mentions,
         ids=ids,
         schema_id=schema_id,
-        namesany_of=namesany_of,
-        namesany_ofcase_sensitive=namesany_ofcase_sensitive,
-        creator_ids=creator_ids,
     )
 
     async with httpx.AsyncClient() as _client:
@@ -203,12 +167,8 @@ async def asyncio(
     modified_at: Union[Unset, str] = UNSET,
     name: Union[Unset, str] = UNSET,
     template_collection_id: Union[Unset, str] = UNSET,
-    mentions: Union[Unset, str] = UNSET,
     ids: Union[Unset, str] = UNSET,
     schema_id: Union[Unset, str] = UNSET,
-    namesany_of: Union[Unset, str] = UNSET,
-    namesany_ofcase_sensitive: Union[Unset, str] = UNSET,
-    creator_ids: Union[Unset, str] = UNSET,
 ) -> Optional[Union[EntryTemplatesPaginatedList, BadRequestError]]:
     """ List entry templates """
 
@@ -220,11 +180,7 @@ async def asyncio(
             modified_at=modified_at,
             name=name,
             template_collection_id=template_collection_id,
-            mentions=mentions,
             ids=ids,
             schema_id=schema_id,
-            namesany_of=namesany_of,
-            namesany_ofcase_sensitive=namesany_ofcase_sensitive,
-            creator_ids=creator_ids,
         )
     ).parsed
