@@ -32,7 +32,7 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[LegacyWorkflowSampleList]:
     if response.status_code == 200:
-        response_200 = LegacyWorkflowSampleList.from_dict(response.json())
+        response_200 = LegacyWorkflowSampleList.from_dict(response.json(), strict=False)
 
         return response_200
     return None
