@@ -152,11 +152,11 @@ def _parse_response(
     *, response: httpx.Response
 ) -> Optional[Union[WorkflowTasksPaginatedList, BadRequestError]]:
     if response.status_code == 200:
-        response_200 = WorkflowTasksPaginatedList.from_dict(response.json())
+        response_200 = WorkflowTasksPaginatedList.from_dict(response.json(), strict=False)
 
         return response_200
     if response.status_code == 400:
-        response_400 = BadRequestError.from_dict(response.json())
+        response_400 = BadRequestError.from_dict(response.json(), strict=False)
 
         return response_400
     return None
