@@ -27,6 +27,7 @@ class AssayResult:
     _fields: Union[Unset, Fields] = UNSET
     _id: Union[Unset, str] = UNSET
     _is_reviewed: Union[Unset, bool] = UNSET
+    _modified_at: Union[Unset, datetime.datetime] = UNSET
     _project_id: Union[Unset, None, str] = UNSET
     _schema: Union[Unset, SchemaSummary] = UNSET
     _validation_comment: Union[Unset, str] = UNSET
@@ -43,6 +44,7 @@ class AssayResult:
         fields.append("fields={}".format(repr(self._fields)))
         fields.append("id={}".format(repr(self._id)))
         fields.append("is_reviewed={}".format(repr(self._is_reviewed)))
+        fields.append("modified_at={}".format(repr(self._modified_at)))
         fields.append("project_id={}".format(repr(self._project_id)))
         fields.append("schema={}".format(repr(self._schema)))
         fields.append("validation_comment={}".format(repr(self._validation_comment)))
@@ -74,6 +76,10 @@ class AssayResult:
 
         id = self._id
         is_reviewed = self._is_reviewed
+        modified_at: Union[Unset, str] = UNSET
+        if not isinstance(self._modified_at, Unset):
+            modified_at = self._modified_at.isoformat()
+
         project_id = self._project_id
         schema: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self._schema, Unset):
@@ -101,6 +107,8 @@ class AssayResult:
             field_dict["id"] = id
         if is_reviewed is not UNSET:
             field_dict["isReviewed"] = is_reviewed
+        if modified_at is not UNSET:
+            field_dict["modifiedAt"] = modified_at
         if project_id is not UNSET:
             field_dict["projectId"] = project_id
         if schema is not UNSET:
@@ -113,20 +121,24 @@ class AssayResult:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_created_at() -> Union[Unset, datetime.datetime]:
             created_at: Union[Unset, datetime.datetime] = UNSET
@@ -136,91 +148,157 @@ class AssayResult:
 
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_creator() -> Union[Unset, UserSummary]:
-            creator: Union[Unset, UserSummary] = UNSET
+            creator: Union[Unset, Union[Unset, UserSummary]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = UserSummary.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, UserSummary], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, UserSummary], UNSET)
 
         def get_entry_id() -> Union[Unset, None, str]:
             entry_id = d.pop("entryId")
             return entry_id
 
-        entry_id = get_entry_id() if "entryId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            entry_id = get_entry_id()
+        except KeyError:
+            if strict:
+                raise
+            entry_id = cast(Union[Unset, None, str], UNSET)
 
         def get_field_validation() -> Union[Unset, AssayResultFieldValidation]:
-            field_validation: Union[Unset, AssayResultFieldValidation] = UNSET
+            field_validation: Union[Unset, Union[Unset, AssayResultFieldValidation]] = UNSET
             _field_validation = d.pop("fieldValidation")
+
             if not isinstance(_field_validation, Unset):
                 field_validation = AssayResultFieldValidation.from_dict(_field_validation)
 
             return field_validation
 
-        field_validation = (
-            get_field_validation()
-            if "fieldValidation" in d
-            else cast(Union[Unset, AssayResultFieldValidation], UNSET)
-        )
+        try:
+            field_validation = get_field_validation()
+        except KeyError:
+            if strict:
+                raise
+            field_validation = cast(Union[Unset, AssayResultFieldValidation], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_is_reviewed() -> Union[Unset, bool]:
             is_reviewed = d.pop("isReviewed")
             return is_reviewed
 
-        is_reviewed = get_is_reviewed() if "isReviewed" in d else cast(Union[Unset, bool], UNSET)
+        try:
+            is_reviewed = get_is_reviewed()
+        except KeyError:
+            if strict:
+                raise
+            is_reviewed = cast(Union[Unset, bool], UNSET)
+
+        def get_modified_at() -> Union[Unset, datetime.datetime]:
+            modified_at: Union[Unset, datetime.datetime] = UNSET
+            _modified_at = d.pop("modifiedAt")
+            if _modified_at is not None and not isinstance(_modified_at, Unset):
+                modified_at = isoparse(cast(str, _modified_at))
+
+            return modified_at
+
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_project_id() -> Union[Unset, None, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, None, str], UNSET)
 
         def get_schema() -> Union[Unset, SchemaSummary]:
-            schema: Union[Unset, SchemaSummary] = UNSET
+            schema: Union[Unset, Union[Unset, SchemaSummary]] = UNSET
             _schema = d.pop("schema")
+
             if not isinstance(_schema, Unset):
                 schema = SchemaSummary.from_dict(_schema)
 
             return schema
 
-        schema = get_schema() if "schema" in d else cast(Union[Unset, SchemaSummary], UNSET)
+        try:
+            schema = get_schema()
+        except KeyError:
+            if strict:
+                raise
+            schema = cast(Union[Unset, SchemaSummary], UNSET)
 
         def get_validation_comment() -> Union[Unset, str]:
             validation_comment = d.pop("validationComment")
             return validation_comment
 
-        validation_comment = (
-            get_validation_comment() if "validationComment" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            validation_comment = get_validation_comment()
+        except KeyError:
+            if strict:
+                raise
+            validation_comment = cast(Union[Unset, str], UNSET)
 
         def get_validation_status() -> Union[Unset, str]:
             validation_status = d.pop("validationStatus")
             return validation_status
 
-        validation_status = (
-            get_validation_status() if "validationStatus" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            validation_status = get_validation_status()
+        except KeyError:
+            if strict:
+                raise
+            validation_status = cast(Union[Unset, str], UNSET)
 
         assay_result = cls(
             archive_record=archive_record,
@@ -231,6 +309,7 @@ class AssayResult:
             fields=fields,
             id=id,
             is_reviewed=is_reviewed,
+            modified_at=modified_at,
             project_id=project_id,
             schema=schema,
             validation_comment=validation_comment,
@@ -376,6 +455,21 @@ class AssayResult:
     def is_reviewed(self) -> None:
         self._is_reviewed = UNSET
 
+    @property
+    def modified_at(self) -> datetime.datetime:
+        """ DateTime at which the the result was last modified """
+        if isinstance(self._modified_at, Unset):
+            raise NotPresentError(self, "modified_at")
+        return self._modified_at
+
+    @modified_at.setter
+    def modified_at(self, value: datetime.datetime) -> None:
+        self._modified_at = value
+
+    @modified_at.deleter
+    def modified_at(self) -> None:
+        self._modified_at = UNSET
+
     @property
     def project_id(self) -> Optional[str]:
         """ ID of the project to insert the result into """
