@@ -46,30 +46,38 @@ class AssayResultSchemasPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_assay_result_schemas() -> Union[Unset, List[AssayResultSchema]]:
             assay_result_schemas = []
             _assay_result_schemas = d.pop("assayResultSchemas")
             for assay_result_schemas_item_data in _assay_result_schemas or []:
-                assay_result_schemas_item = AssayResultSchema.from_dict(assay_result_schemas_item_data)
+                assay_result_schemas_item = AssayResultSchema.from_dict(
+                    assay_result_schemas_item_data, strict=False
+                )
 
                 assay_result_schemas.append(assay_result_schemas_item)
 
             return assay_result_schemas
 
-        assay_result_schemas = (
-            get_assay_result_schemas()
-            if "assayResultSchemas" in d
-            else cast(Union[Unset, List[AssayResultSchema]], UNSET)
-        )
+        try:
+            assay_result_schemas = get_assay_result_schemas()
+        except KeyError:
+            if strict:
+                raise
+            assay_result_schemas = cast(Union[Unset, List[AssayResultSchema]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         assay_result_schemas_paginated_list = cls(
             assay_result_schemas=assay_result_schemas,
