@@ -132,7 +132,7 @@ class AssayRunSchema:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
+        # Allow the model to serialize even if it was created outside of the constructor, circumventing validation
         if automation_input_file_configs is not UNSET:
             field_dict["automationInputFileConfigs"] = automation_input_file_configs
         if automation_output_file_configs is not UNSET:
@@ -159,7 +159,7 @@ class AssayRunSchema:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_automation_input_file_configs() -> Union[
@@ -169,18 +169,21 @@ class AssayRunSchema:
             _automation_input_file_configs = d.pop("automationInputFileConfigs")
             for automation_input_file_configs_item_data in _automation_input_file_configs or []:
                 automation_input_file_configs_item = AssayRunSchemaAutomationInputFileConfigsItem.from_dict(
-                    automation_input_file_configs_item_data
+                    automation_input_file_configs_item_data, strict=False
                 )
 
                 automation_input_file_configs.append(automation_input_file_configs_item)
 
             return automation_input_file_configs
 
-        automation_input_file_configs = (
-            get_automation_input_file_configs()
-            if "automationInputFileConfigs" in d
-            else cast(Union[Unset, List[AssayRunSchemaAutomationInputFileConfigsItem]], UNSET)
-        )
+        try:
+            automation_input_file_configs = get_automation_input_file_configs()
+        except KeyError:
+            if strict:
+                raise
+            automation_input_file_configs = cast(
+                Union[Unset, List[AssayRunSchemaAutomationInputFileConfigsItem]], UNSET
+            )
 
         def get_automation_output_file_configs() -> Union[
             Unset, List[AssayRunSchemaAutomationOutputFileConfigsItem]
@@ -189,18 +192,21 @@ class AssayRunSchema:
             _automation_output_file_configs = d.pop("automationOutputFileConfigs")
             for automation_output_file_configs_item_data in _automation_output_file_configs or []:
                 automation_output_file_configs_item = AssayRunSchemaAutomationOutputFileConfigsItem.from_dict(
-                    automation_output_file_configs_item_data
+                    automation_output_file_configs_item_data, strict=False
                 )
 
                 automation_output_file_configs.append(automation_output_file_configs_item)
 
             return automation_output_file_configs
 
-        automation_output_file_configs = (
-            get_automation_output_file_configs()
-            if "automationOutputFileConfigs" in d
-            else cast(Union[Unset, List[AssayRunSchemaAutomationOutputFileConfigsItem]], UNSET)
-        )
+        try:
+            automation_output_file_configs = get_automation_output_file_configs()
+        except KeyError:
+            if strict:
+                raise
+            automation_output_file_configs = cast(
+                Union[Unset, List[AssayRunSchemaAutomationOutputFileConfigsItem]], UNSET
+            )
 
         def get_modified_at() -> Union[Unset, datetime.datetime]:
             modified_at: Union[Unset, datetime.datetime] = UNSET
@@ -210,10 +216,15 @@ class AssayRunSchema:
 
             return modified_at
 
-        modified_at = get_modified_at() if "modifiedAt" in d else cast(Union[Unset, datetime.datetime], UNSET)
+        try:
+            modified_at = get_modified_at()
+        except KeyError:
+            if strict:
+                raise
+            modified_at = cast(Union[Unset, datetime.datetime], UNSET)
 
         def get_type() -> Union[Unset, AssayRunSchemaType]:
-            type = None
+            type = UNSET
             _type = d.pop("type")
             if _type is not None and _type is not UNSET:
                 try:
@@ -223,45 +234,66 @@ class AssayRunSchema:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, AssayRunSchemaType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, AssayRunSchemaType], UNSET)
 
         def get_derived_from() -> Union[Unset, None, str]:
             derived_from = d.pop("derivedFrom")
             return derived_from
 
-        derived_from = get_derived_from() if "derivedFrom" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            derived_from = get_derived_from()
+        except KeyError:
+            if strict:
+                raise
+            derived_from = cast(Union[Unset, None, str], UNSET)
 
         def get_organization() -> Union[Unset, BaseAssaySchemaOrganization]:
-            organization: Union[Unset, BaseAssaySchemaOrganization] = UNSET
+            organization: Union[Unset, Union[Unset, BaseAssaySchemaOrganization]] = UNSET
             _organization = d.pop("organization")
+
             if not isinstance(_organization, Unset):
                 organization = BaseAssaySchemaOrganization.from_dict(_organization)
 
             return organization
 
-        organization = (
-            get_organization()
-            if "organization" in d
-            else cast(Union[Unset, BaseAssaySchemaOrganization], UNSET)
-        )
+        try:
+            organization = get_organization()
+        except KeyError:
+            if strict:
+                raise
+            organization = cast(Union[Unset, BaseAssaySchemaOrganization], UNSET)
 
         def get_system_name() -> Union[Unset, str]:
             system_name = d.pop("systemName")
             return system_name
 
-        system_name = get_system_name() if "systemName" in d else cast(Union[Unset, str], UNSET)
+        try:
+            system_name = get_system_name()
+        except KeyError:
+            if strict:
+                raise
+            system_name = cast(Union[Unset, str], UNSET)
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_field_definitions() -> Union[
             Unset,
@@ -301,7 +333,7 @@ class AssayRunSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SimpleFieldDefinition.from_dict(data)
+                        field_definitions_item = SimpleFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -309,7 +341,7 @@ class AssayRunSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = IntegerFieldDefinition.from_dict(data)
+                        field_definitions_item = IntegerFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -317,7 +349,7 @@ class AssayRunSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = FloatFieldDefinition.from_dict(data)
+                        field_definitions_item = FloatFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -325,7 +357,7 @@ class AssayRunSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = DropdownFieldDefinition.from_dict(data)
+                        field_definitions_item = DropdownFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -333,7 +365,7 @@ class AssayRunSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data)
+                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -346,10 +378,12 @@ class AssayRunSchema:
 
             return field_definitions
 
-        field_definitions = (
-            get_field_definitions()
-            if "fieldDefinitions" in d
-            else cast(
+        try:
+            field_definitions = get_field_definitions()
+        except KeyError:
+            if strict:
+                raise
+            field_definitions = cast(
                 Union[
                     Unset,
                     List[
@@ -365,19 +399,28 @@ class AssayRunSchema:
                 ],
                 UNSET,
             )
-        )
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         assay_run_schema = cls(
             automation_input_file_configs=automation_input_file_configs,
