@@ -64,44 +64,62 @@ class AutomationFile:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_assay_run_id() -> Union[Unset, str]:
             assay_run_id = d.pop("assayRunId")
             return assay_run_id
 
-        assay_run_id = get_assay_run_id() if "assayRunId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            assay_run_id = get_assay_run_id()
+        except KeyError:
+            if strict:
+                raise
+            assay_run_id = cast(Union[Unset, str], UNSET)
 
         def get_automation_file_config() -> Union[Unset, AutomationFileAutomationFileConfig]:
-            automation_file_config: Union[Unset, AutomationFileAutomationFileConfig] = UNSET
+            automation_file_config: Union[Unset, Union[Unset, AutomationFileAutomationFileConfig]] = UNSET
             _automation_file_config = d.pop("automationFileConfig")
+
             if not isinstance(_automation_file_config, Unset):
                 automation_file_config = AutomationFileAutomationFileConfig.from_dict(_automation_file_config)
 
             return automation_file_config
 
-        automation_file_config = (
-            get_automation_file_config()
-            if "automationFileConfig" in d
-            else cast(Union[Unset, AutomationFileAutomationFileConfig], UNSET)
-        )
+        try:
+            automation_file_config = get_automation_file_config()
+        except KeyError:
+            if strict:
+                raise
+            automation_file_config = cast(Union[Unset, AutomationFileAutomationFileConfig], UNSET)
 
         def get_file() -> Union[Unset, None, Blob]:
             file = None
             _file = d.pop("file")
+
             if _file is not None and not isinstance(_file, Unset):
                 file = Blob.from_dict(_file)
 
             return file
 
-        file = get_file() if "file" in d else cast(Union[Unset, None, Blob], UNSET)
+        try:
+            file = get_file()
+        except KeyError:
+            if strict:
+                raise
+            file = cast(Union[Unset, None, Blob], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_status() -> Union[Unset, AutomationFileStatus]:
             status = UNSET
@@ -114,7 +132,12 @@ class AutomationFile:
 
             return status
 
-        status = get_status() if "status" in d else cast(Union[Unset, AutomationFileStatus], UNSET)
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(Union[Unset, AutomationFileStatus], UNSET)
 
         automation_file = cls(
             assay_run_id=assay_run_id,
