@@ -33,14 +33,19 @@ class AutomationFileAutomationFileConfig:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         automation_file_automation_file_config = cls(
             name=name,
