@@ -46,7 +46,7 @@ class AutomationOutputProcessorsPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_automation_output_processors() -> Union[Unset, List[AutomationOutputProcessor]]:
@@ -54,24 +54,30 @@ class AutomationOutputProcessorsPaginatedList:
             _automation_output_processors = d.pop("automationOutputProcessors")
             for automation_output_processors_item_data in _automation_output_processors or []:
                 automation_output_processors_item = AutomationOutputProcessor.from_dict(
-                    automation_output_processors_item_data
+                    automation_output_processors_item_data, strict=False
                 )
 
                 automation_output_processors.append(automation_output_processors_item)
 
             return automation_output_processors
 
-        automation_output_processors = (
-            get_automation_output_processors()
-            if "automationOutputProcessors" in d
-            else cast(Union[Unset, List[AutomationOutputProcessor]], UNSET)
-        )
+        try:
+            automation_output_processors = get_automation_output_processors()
+        except KeyError:
+            if strict:
+                raise
+            automation_output_processors = cast(Union[Unset, List[AutomationOutputProcessor]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         automation_output_processors_paginated_list = cls(
             automation_output_processors=automation_output_processors,
