@@ -38,20 +38,30 @@ class BadRequestErrorBulkErrorErrorsItem:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_index() -> Union[Unset, float]:
             index = d.pop("index")
             return index
 
-        index = get_index() if "index" in d else cast(Union[Unset, float], UNSET)
+        try:
+            index = get_index()
+        except KeyError:
+            if strict:
+                raise
+            index = cast(Union[Unset, float], UNSET)
 
         def get_message() -> Union[Unset, str]:
             message = d.pop("message")
             return message
 
-        message = get_message() if "message" in d else cast(Union[Unset, str], UNSET)
+        try:
+            message = get_message()
+        except KeyError:
+            if strict:
+                raise
+            message = cast(Union[Unset, str], UNSET)
 
         bad_request_error_bulk_error_errors_item = cls(
             index=index,
