@@ -58,7 +58,7 @@ class BulkCreateFeaturesAsyncTask:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_status() -> AsyncTaskStatus:
@@ -70,37 +70,55 @@ class BulkCreateFeaturesAsyncTask:
 
             return status
 
-        status = get_status() if "status" in d else cast(AsyncTaskStatus, UNSET)
+        try:
+            status = get_status()
+        except KeyError:
+            if strict:
+                raise
+            status = cast(AsyncTaskStatus, UNSET)
 
         def get_response() -> Union[Unset, BulkCreateFeaturesAsyncTaskResponse]:
-            response: Union[Unset, BulkCreateFeaturesAsyncTaskResponse] = UNSET
+            response: Union[Unset, Union[Unset, BulkCreateFeaturesAsyncTaskResponse]] = UNSET
             _response = d.pop("response")
+
             if not isinstance(_response, Unset):
                 response = BulkCreateFeaturesAsyncTaskResponse.from_dict(_response)
 
             return response
 
-        response = (
-            get_response()
-            if "response" in d
-            else cast(Union[Unset, BulkCreateFeaturesAsyncTaskResponse], UNSET)
-        )
+        try:
+            response = get_response()
+        except KeyError:
+            if strict:
+                raise
+            response = cast(Union[Unset, BulkCreateFeaturesAsyncTaskResponse], UNSET)
 
         def get_errors() -> Union[Unset, AsyncTaskErrors]:
-            errors: Union[Unset, AsyncTaskErrors] = UNSET
+            errors: Union[Unset, Union[Unset, AsyncTaskErrors]] = UNSET
             _errors = d.pop("errors")
+
             if not isinstance(_errors, Unset):
                 errors = AsyncTaskErrors.from_dict(_errors)
 
             return errors
 
-        errors = get_errors() if "errors" in d else cast(Union[Unset, AsyncTaskErrors], UNSET)
+        try:
+            errors = get_errors()
+        except KeyError:
+            if strict:
+                raise
+            errors = cast(Union[Unset, AsyncTaskErrors], UNSET)
 
         def get_message() -> Union[Unset, str]:
             message = d.pop("message")
             return message
 
-        message = get_message() if "message" in d else cast(Union[Unset, str], UNSET)
+        try:
+            message = get_message()
+        except KeyError:
+            if strict:
+                raise
+            message = cast(Union[Unset, str], UNSET)
 
         bulk_create_features_async_task = cls(
             status=status,
