@@ -59,50 +59,79 @@ class ContainerCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_schema_id() -> str:
             schema_id = d.pop("schemaId")
             return schema_id
 
-        schema_id = get_schema_id() if "schemaId" in d else cast(str, UNSET)
+        try:
+            schema_id = get_schema_id()
+        except KeyError:
+            if strict:
+                raise
+            schema_id = cast(str, UNSET)
 
         def get_barcode() -> Union[Unset, str]:
             barcode = d.pop("barcode")
             return barcode
 
-        barcode = get_barcode() if "barcode" in d else cast(Union[Unset, str], UNSET)
+        try:
+            barcode = get_barcode()
+        except KeyError:
+            if strict:
+                raise
+            barcode = cast(Union[Unset, str], UNSET)
 
         def get_project_id() -> Union[Unset, None, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, None, str], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_parent_storage_id() -> Union[Unset, str]:
             parent_storage_id = d.pop("parentStorageId")
             return parent_storage_id
 
-        parent_storage_id = (
-            get_parent_storage_id() if "parentStorageId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            parent_storage_id = get_parent_storage_id()
+        except KeyError:
+            if strict:
+                raise
+            parent_storage_id = cast(Union[Unset, str], UNSET)
 
         container_create = cls(
             schema_id=schema_id,
@@ -183,7 +212,7 @@ class ContainerCreate:
 
     @property
     def parent_storage_id(self) -> str:
-        """ ID of containing parent storage, can also specify a coordinate for plates and boxes (e.g. plt_2bAks9dx:a2). """
+        """ ID of containing parent inventory, can also specify a coordinate for plates and boxes (e.g. plt_2bAks9dx:a2). """
         if isinstance(self._parent_storage_id, Unset):
             raise NotPresentError(self, "parent_storage_id")
         return self._parent_storage_id
