@@ -60,56 +60,73 @@ class ContainerTransferBase:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_source_batch_id() -> Union[Unset, str]:
             source_batch_id = d.pop("sourceBatchId")
             return source_batch_id
 
-        source_batch_id = get_source_batch_id() if "sourceBatchId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            source_batch_id = get_source_batch_id()
+        except KeyError:
+            if strict:
+                raise
+            source_batch_id = cast(Union[Unset, str], UNSET)
 
         def get_source_container_id() -> Union[Unset, str]:
             source_container_id = d.pop("sourceContainerId")
             return source_container_id
 
-        source_container_id = (
-            get_source_container_id() if "sourceContainerId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            source_container_id = get_source_container_id()
+        except KeyError:
+            if strict:
+                raise
+            source_container_id = cast(Union[Unset, str], UNSET)
 
         def get_source_entity_id() -> Union[Unset, str]:
             source_entity_id = d.pop("sourceEntityId")
             return source_entity_id
 
-        source_entity_id = get_source_entity_id() if "sourceEntityId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            source_entity_id = get_source_entity_id()
+        except KeyError:
+            if strict:
+                raise
+            source_entity_id = cast(Union[Unset, str], UNSET)
 
         def get_transfer_quantity() -> Union[Unset, ContainerQuantity]:
-            transfer_quantity: Union[Unset, ContainerQuantity] = UNSET
+            transfer_quantity: Union[Unset, Union[Unset, ContainerQuantity]] = UNSET
             _transfer_quantity = d.pop("transferQuantity")
+
             if not isinstance(_transfer_quantity, Unset):
                 transfer_quantity = ContainerQuantity.from_dict(_transfer_quantity)
 
             return transfer_quantity
 
-        transfer_quantity = (
-            get_transfer_quantity()
-            if "transferQuantity" in d
-            else cast(Union[Unset, ContainerQuantity], UNSET)
-        )
+        try:
+            transfer_quantity = get_transfer_quantity()
+        except KeyError:
+            if strict:
+                raise
+            transfer_quantity = cast(Union[Unset, ContainerQuantity], UNSET)
 
         def get_transfer_volume() -> Union[Unset, DeprecatedContainerVolumeForInput]:
-            transfer_volume: Union[Unset, DeprecatedContainerVolumeForInput] = UNSET
+            transfer_volume: Union[Unset, Union[Unset, DeprecatedContainerVolumeForInput]] = UNSET
             _transfer_volume = d.pop("transferVolume")
+
             if not isinstance(_transfer_volume, Unset):
                 transfer_volume = DeprecatedContainerVolumeForInput.from_dict(_transfer_volume)
 
             return transfer_volume
 
-        transfer_volume = (
-            get_transfer_volume()
-            if "transferVolume" in d
-            else cast(Union[Unset, DeprecatedContainerVolumeForInput], UNSET)
-        )
+        try:
+            transfer_volume = get_transfer_volume()
+        except KeyError:
+            if strict:
+                raise
+            transfer_volume = cast(Union[Unset, DeprecatedContainerVolumeForInput], UNSET)
 
         container_transfer_base = cls(
             source_batch_id=source_batch_id,
