@@ -67,60 +67,89 @@ class ContainerUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_project_id() -> Union[Unset, None, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, None, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, None, str], UNSET)
 
         def get_quantity() -> Union[Unset, ContainerQuantity]:
-            quantity: Union[Unset, ContainerQuantity] = UNSET
+            quantity: Union[Unset, Union[Unset, ContainerQuantity]] = UNSET
             _quantity = d.pop("quantity")
+
             if not isinstance(_quantity, Unset):
                 quantity = ContainerQuantity.from_dict(_quantity)
 
             return quantity
 
-        quantity = get_quantity() if "quantity" in d else cast(Union[Unset, ContainerQuantity], UNSET)
+        try:
+            quantity = get_quantity()
+        except KeyError:
+            if strict:
+                raise
+            quantity = cast(Union[Unset, ContainerQuantity], UNSET)
 
         def get_volume() -> Union[Unset, DeprecatedContainerVolumeForInput]:
-            volume: Union[Unset, DeprecatedContainerVolumeForInput] = UNSET
+            volume: Union[Unset, Union[Unset, DeprecatedContainerVolumeForInput]] = UNSET
             _volume = d.pop("volume")
+
             if not isinstance(_volume, Unset):
                 volume = DeprecatedContainerVolumeForInput.from_dict(_volume)
 
             return volume
 
-        volume = (
-            get_volume() if "volume" in d else cast(Union[Unset, DeprecatedContainerVolumeForInput], UNSET)
-        )
+        try:
+            volume = get_volume()
+        except KeyError:
+            if strict:
+                raise
+            volume = cast(Union[Unset, DeprecatedContainerVolumeForInput], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_parent_storage_id() -> Union[Unset, str]:
             parent_storage_id = d.pop("parentStorageId")
             return parent_storage_id
 
-        parent_storage_id = (
-            get_parent_storage_id() if "parentStorageId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            parent_storage_id = get_parent_storage_id()
+        except KeyError:
+            if strict:
+                raise
+            parent_storage_id = cast(Union[Unset, str], UNSET)
 
         container_update = cls(
             project_id=project_id,
@@ -207,7 +236,7 @@ class ContainerUpdate:
 
     @property
     def parent_storage_id(self) -> str:
-        """ ID of containing parent storage, can also specify a coordinate for plates and boxes (e.g. plt_2bAks9dx:a2). """
+        """ ID of containing parent inventory, can also specify a coordinate for plates and boxes (e.g. plt_2bAks9dx:a2). """
         if isinstance(self._parent_storage_id, Unset):
             raise NotPresentError(self, "parent_storage_id")
         return self._parent_storage_id
