@@ -35,20 +35,25 @@ class ContainersBulkUpdateRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_containers() -> List[ContainerBulkUpdateItem]:
             containers = []
             _containers = d.pop("containers")
             for containers_item_data in _containers:
-                containers_item = ContainerBulkUpdateItem.from_dict(containers_item_data)
+                containers_item = ContainerBulkUpdateItem.from_dict(containers_item_data, strict=False)
 
                 containers.append(containers_item)
 
             return containers
 
-        containers = get_containers() if "containers" in d else cast(List[ContainerBulkUpdateItem], UNSET)
+        try:
+            containers = get_containers()
+        except KeyError:
+            if strict:
+                raise
+            containers = cast(List[ContainerBulkUpdateItem], UNSET)
 
         containers_bulk_update_request = cls(
             containers=containers,
