@@ -40,24 +40,25 @@ class DeprecatedEntitySchemasList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entity_schemas() -> Union[Unset, List[DeprecatedEntitySchema]]:
             entity_schemas = []
             _entity_schemas = d.pop("entitySchemas")
             for entity_schemas_item_data in _entity_schemas or []:
-                entity_schemas_item = DeprecatedEntitySchema.from_dict(entity_schemas_item_data)
+                entity_schemas_item = DeprecatedEntitySchema.from_dict(entity_schemas_item_data, strict=False)
 
                 entity_schemas.append(entity_schemas_item)
 
             return entity_schemas
 
-        entity_schemas = (
-            get_entity_schemas()
-            if "entitySchemas" in d
-            else cast(Union[Unset, List[DeprecatedEntitySchema]], UNSET)
-        )
+        try:
+            entity_schemas = get_entity_schemas()
+        except KeyError:
+            if strict:
+                raise
+            entity_schemas = cast(Union[Unset, List[DeprecatedEntitySchema]], UNSET)
 
         deprecated_entity_schemas_list = cls(
             entity_schemas=entity_schemas,
