@@ -43,7 +43,7 @@ class DnaOligosArchivalChange:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_batch_ids() -> Union[Unset, List[str]]:
@@ -51,14 +51,24 @@ class DnaOligosArchivalChange:
 
             return batch_ids
 
-        batch_ids = get_batch_ids() if "batchIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            batch_ids = get_batch_ids()
+        except KeyError:
+            if strict:
+                raise
+            batch_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_dna_oligo_ids() -> Union[Unset, List[str]]:
             dna_oligo_ids = cast(List[str], d.pop("dnaOligoIds"))
 
             return dna_oligo_ids
 
-        dna_oligo_ids = get_dna_oligo_ids() if "dnaOligoIds" in d else cast(Union[Unset, List[str]], UNSET)
+        try:
+            dna_oligo_ids = get_dna_oligo_ids()
+        except KeyError:
+            if strict:
+                raise
+            dna_oligo_ids = cast(Union[Unset, List[str]], UNSET)
 
         dna_oligos_archival_change = cls(
             batch_ids=batch_ids,
