@@ -43,28 +43,36 @@ class EntryTemplatesPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_entry_templates() -> Union[Unset, List[EntryTemplate]]:
             entry_templates = []
             _entry_templates = d.pop("entryTemplates")
             for entry_templates_item_data in _entry_templates or []:
-                entry_templates_item = EntryTemplate.from_dict(entry_templates_item_data)
+                entry_templates_item = EntryTemplate.from_dict(entry_templates_item_data, strict=False)
 
                 entry_templates.append(entry_templates_item)
 
             return entry_templates
 
-        entry_templates = (
-            get_entry_templates() if "entryTemplates" in d else cast(Union[Unset, List[EntryTemplate]], UNSET)
-        )
+        try:
+            entry_templates = get_entry_templates()
+        except KeyError:
+            if strict:
+                raise
+            entry_templates = cast(Union[Unset, List[EntryTemplate]], UNSET)
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         entry_templates_paginated_list = cls(
             entry_templates=entry_templates,
