@@ -30,14 +30,19 @@ class ExportItemRequest:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_id() -> str:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(str, UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(str, UNSET)
 
         export_item_request = cls(
             id=id,
