@@ -41,7 +41,7 @@ class FindMatchingRegionsAsyncTaskResponseAaSequenceMatchesItem:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_matching_aa_sequence_ids() -> Union[Unset, List[str]]:
@@ -49,19 +49,23 @@ class FindMatchingRegionsAsyncTaskResponseAaSequenceMatchesItem:
 
             return matching_aa_sequence_ids
 
-        matching_aa_sequence_ids = (
-            get_matching_aa_sequence_ids()
-            if "matchingAASequenceIds" in d
-            else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            matching_aa_sequence_ids = get_matching_aa_sequence_ids()
+        except KeyError:
+            if strict:
+                raise
+            matching_aa_sequence_ids = cast(Union[Unset, List[str]], UNSET)
 
         def get_target_aa_sequence_id() -> Union[Unset, str]:
             target_aa_sequence_id = d.pop("targetAASequenceId")
             return target_aa_sequence_id
 
-        target_aa_sequence_id = (
-            get_target_aa_sequence_id() if "targetAASequenceId" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            target_aa_sequence_id = get_target_aa_sequence_id()
+        except KeyError:
+            if strict:
+                raise
+            target_aa_sequence_id = cast(Union[Unset, str], UNSET)
 
         find_matching_regions_async_task_response_aa_sequence_matches_item = cls(
             matching_aa_sequence_ids=matching_aa_sequence_ids,
