@@ -42,28 +42,36 @@ class LabAutomationTransformUpdate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_blob_id() -> Union[Unset, str]:
             blob_id = d.pop("blobId")
             return blob_id
 
-        blob_id = get_blob_id() if "blobId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            blob_id = get_blob_id()
+        except KeyError:
+            if strict:
+                raise
+            blob_id = cast(Union[Unset, str], UNSET)
 
         def get_errors() -> Union[Unset, List[LabAutomationBenchlingAppError]]:
             errors = []
             _errors = d.pop("errors")
             for errors_item_data in _errors or []:
-                errors_item = LabAutomationBenchlingAppError.from_dict(errors_item_data)
+                errors_item = LabAutomationBenchlingAppError.from_dict(errors_item_data, strict=False)
 
                 errors.append(errors_item)
 
             return errors
 
-        errors = (
-            get_errors() if "errors" in d else cast(Union[Unset, List[LabAutomationBenchlingAppError]], UNSET)
-        )
+        try:
+            errors = get_errors()
+        except KeyError:
+            if strict:
+                raise
+            errors = cast(Union[Unset, List[LabAutomationBenchlingAppError]], UNSET)
 
         lab_automation_transform_update = cls(
             blob_id=blob_id,
