@@ -110,7 +110,7 @@ class LocationSchema:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_type() -> Union[Unset, LocationSchemaType]:
@@ -124,31 +124,50 @@ class LocationSchema:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, LocationSchemaType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, LocationSchemaType], UNSET)
 
         def get_prefix() -> Union[Unset, str]:
             prefix = d.pop("prefix")
             return prefix
 
-        prefix = get_prefix() if "prefix" in d else cast(Union[Unset, str], UNSET)
+        try:
+            prefix = get_prefix()
+        except KeyError:
+            if strict:
+                raise
+            prefix = cast(Union[Unset, str], UNSET)
 
         def get_registry_id() -> Union[Unset, str]:
             registry_id = d.pop("registryId")
             return registry_id
 
-        registry_id = get_registry_id() if "registryId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            registry_id = get_registry_id()
+        except KeyError:
+            if strict:
+                raise
+            registry_id = cast(Union[Unset, str], UNSET)
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_field_definitions() -> Union[
             Unset,
@@ -188,7 +207,7 @@ class LocationSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SimpleFieldDefinition.from_dict(data)
+                        field_definitions_item = SimpleFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -196,7 +215,7 @@ class LocationSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = IntegerFieldDefinition.from_dict(data)
+                        field_definitions_item = IntegerFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -204,7 +223,7 @@ class LocationSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = FloatFieldDefinition.from_dict(data)
+                        field_definitions_item = FloatFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -212,7 +231,7 @@ class LocationSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = DropdownFieldDefinition.from_dict(data)
+                        field_definitions_item = DropdownFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -220,7 +239,7 @@ class LocationSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data)
+                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -233,10 +252,12 @@ class LocationSchema:
 
             return field_definitions
 
-        field_definitions = (
-            get_field_definitions()
-            if "fieldDefinitions" in d
-            else cast(
+        try:
+            field_definitions = get_field_definitions()
+        except KeyError:
+            if strict:
+                raise
+            field_definitions = cast(
                 Union[
                     Unset,
                     List[
@@ -252,19 +273,28 @@ class LocationSchema:
                 ],
                 UNSET,
             )
-        )
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         location_schema = cls(
             type=type,
