@@ -47,7 +47,7 @@ class OAuthBadRequestErrorError:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_type() -> Union[Unset, OAuthBadRequestErrorErrorType]:
@@ -61,19 +61,34 @@ class OAuthBadRequestErrorError:
 
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, OAuthBadRequestErrorErrorType], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, OAuthBadRequestErrorErrorType], UNSET)
 
         def get_message() -> Union[Unset, str]:
             message = d.pop("message")
             return message
 
-        message = get_message() if "message" in d else cast(Union[Unset, str], UNSET)
+        try:
+            message = get_message()
+        except KeyError:
+            if strict:
+                raise
+            message = cast(Union[Unset, str], UNSET)
 
         def get_user_message() -> Union[Unset, str]:
             user_message = d.pop("userMessage")
             return user_message
 
-        user_message = get_user_message() if "userMessage" in d else cast(Union[Unset, str], UNSET)
+        try:
+            user_message = get_user_message()
+        except KeyError:
+            if strict:
+                raise
+            user_message = cast(Union[Unset, str], UNSET)
 
         o_auth_bad_request_error_error = cls(
             type=type,
