@@ -37,7 +37,7 @@ class ProjectsArchive:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_project_ids() -> List[str]:
@@ -45,7 +45,12 @@ class ProjectsArchive:
 
             return project_ids
 
-        project_ids = get_project_ids() if "projectIds" in d else cast(List[str], UNSET)
+        try:
+            project_ids = get_project_ids()
+        except KeyError:
+            if strict:
+                raise
+            project_ids = cast(List[str], UNSET)
 
         def get_reason() -> ProjectsArchiveReason:
             _reason = d.pop("reason")
@@ -56,7 +61,12 @@ class ProjectsArchive:
 
             return reason
 
-        reason = get_reason() if "reason" in d else cast(ProjectsArchiveReason, UNSET)
+        try:
+            reason = get_reason()
+        except KeyError:
+            if strict:
+                raise
+            reason = cast(ProjectsArchiveReason, UNSET)
 
         projects_archive = cls(
             project_ids=project_ids,
