@@ -159,14 +159,19 @@ class Request:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_api_url() -> Union[Unset, str]:
             api_url = d.pop("apiURL")
             return api_url
 
-        api_url = get_api_url() if "apiURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            api_url = get_api_url()
+        except KeyError:
+            if strict:
+                raise
+            api_url = cast(Union[Unset, str], UNSET)
 
         def get_assignees() -> Union[
             Unset, List[Union[RequestUserAssignee, RequestTeamAssignee, UnknownType]]
@@ -182,7 +187,7 @@ class Request:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        assignees_item = RequestUserAssignee.from_dict(data)
+                        assignees_item = RequestUserAssignee.from_dict(data, strict=True)
 
                         return assignees_item
                     except:  # noqa: E722
@@ -190,7 +195,7 @@ class Request:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        assignees_item = RequestTeamAssignee.from_dict(data)
+                        assignees_item = RequestTeamAssignee.from_dict(data, strict=True)
 
                         return assignees_item
                     except:  # noqa: E722
@@ -203,55 +208,90 @@ class Request:
 
             return assignees
 
-        assignees = (
-            get_assignees()
-            if "assignees" in d
-            else cast(Union[Unset, List[Union[RequestUserAssignee, RequestTeamAssignee, UnknownType]]], UNSET)
-        )
+        try:
+            assignees = get_assignees()
+        except KeyError:
+            if strict:
+                raise
+            assignees = cast(
+                Union[Unset, List[Union[RequestUserAssignee, RequestTeamAssignee, UnknownType]]], UNSET
+            )
 
         def get_created_at() -> Union[Unset, str]:
             created_at = d.pop("createdAt")
             return created_at
 
-        created_at = get_created_at() if "createdAt" in d else cast(Union[Unset, str], UNSET)
+        try:
+            created_at = get_created_at()
+        except KeyError:
+            if strict:
+                raise
+            created_at = cast(Union[Unset, str], UNSET)
 
         def get_creator() -> Union[Unset, RequestCreator]:
-            creator: Union[Unset, RequestCreator] = UNSET
+            creator: Union[Unset, Union[Unset, RequestCreator]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = RequestCreator.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, RequestCreator], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, RequestCreator], UNSET)
 
         def get_display_id() -> Union[Unset, str]:
             display_id = d.pop("displayId")
             return display_id
 
-        display_id = get_display_id() if "displayId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            display_id = get_display_id()
+        except KeyError:
+            if strict:
+                raise
+            display_id = cast(Union[Unset, str], UNSET)
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_project_id() -> Union[Unset, str]:
             project_id = d.pop("projectId")
             return project_id
 
-        project_id = get_project_id() if "projectId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            project_id = get_project_id()
+        except KeyError:
+            if strict:
+                raise
+            project_id = cast(Union[Unset, str], UNSET)
 
         def get_request_status() -> Union[Unset, RequestStatus]:
             request_status = UNSET
@@ -264,35 +304,45 @@ class Request:
 
             return request_status
 
-        request_status = (
-            get_request_status() if "requestStatus" in d else cast(Union[Unset, RequestStatus], UNSET)
-        )
+        try:
+            request_status = get_request_status()
+        except KeyError:
+            if strict:
+                raise
+            request_status = cast(Union[Unset, RequestStatus], UNSET)
 
         def get_requestor() -> Union[Unset, RequestRequestor]:
-            requestor: Union[Unset, RequestRequestor] = UNSET
+            requestor: Union[Unset, Union[Unset, RequestRequestor]] = UNSET
             _requestor = d.pop("requestor")
+
             if not isinstance(_requestor, Unset):
                 requestor = RequestRequestor.from_dict(_requestor)
 
             return requestor
 
-        requestor = get_requestor() if "requestor" in d else cast(Union[Unset, RequestRequestor], UNSET)
+        try:
+            requestor = get_requestor()
+        except KeyError:
+            if strict:
+                raise
+            requestor = cast(Union[Unset, RequestRequestor], UNSET)
 
         def get_sample_groups() -> Union[Unset, List[RequestSampleGroup]]:
             sample_groups = []
             _sample_groups = d.pop("sampleGroups")
             for sample_groups_item_data in _sample_groups or []:
-                sample_groups_item = RequestSampleGroup.from_dict(sample_groups_item_data)
+                sample_groups_item = RequestSampleGroup.from_dict(sample_groups_item_data, strict=False)
 
                 sample_groups.append(sample_groups_item)
 
             return sample_groups
 
-        sample_groups = (
-            get_sample_groups()
-            if "sampleGroups" in d
-            else cast(Union[Unset, List[RequestSampleGroup]], UNSET)
-        )
+        try:
+            sample_groups = get_sample_groups()
+        except KeyError:
+            if strict:
+                raise
+            sample_groups = cast(Union[Unset, List[RequestSampleGroup]], UNSET)
 
         def get_scheduled_on() -> Union[Unset, None, datetime.date]:
             scheduled_on: Union[Unset, None, datetime.date] = UNSET
@@ -302,37 +352,56 @@ class Request:
 
             return scheduled_on
 
-        scheduled_on = (
-            get_scheduled_on() if "scheduledOn" in d else cast(Union[Unset, None, datetime.date], UNSET)
-        )
+        try:
+            scheduled_on = get_scheduled_on()
+        except KeyError:
+            if strict:
+                raise
+            scheduled_on = cast(Union[Unset, None, datetime.date], UNSET)
 
         def get_schema() -> Union[Unset, RequestSchemaProperty]:
-            schema: Union[Unset, RequestSchemaProperty] = UNSET
+            schema: Union[Unset, Union[Unset, RequestSchemaProperty]] = UNSET
             _schema = d.pop("schema")
+
             if not isinstance(_schema, Unset):
                 schema = RequestSchemaProperty.from_dict(_schema)
 
             return schema
 
-        schema = get_schema() if "schema" in d else cast(Union[Unset, RequestSchemaProperty], UNSET)
+        try:
+            schema = get_schema()
+        except KeyError:
+            if strict:
+                raise
+            schema = cast(Union[Unset, RequestSchemaProperty], UNSET)
 
         def get_tasks() -> Union[Unset, List[RequestTask]]:
             tasks = []
             _tasks = d.pop("tasks")
             for tasks_item_data in _tasks or []:
-                tasks_item = RequestTask.from_dict(tasks_item_data)
+                tasks_item = RequestTask.from_dict(tasks_item_data, strict=False)
 
                 tasks.append(tasks_item)
 
             return tasks
 
-        tasks = get_tasks() if "tasks" in d else cast(Union[Unset, List[RequestTask]], UNSET)
+        try:
+            tasks = get_tasks()
+        except KeyError:
+            if strict:
+                raise
+            tasks = cast(Union[Unset, List[RequestTask]], UNSET)
 
         def get_web_url() -> Union[Unset, str]:
             web_url = d.pop("webURL")
             return web_url
 
-        web_url = get_web_url() if "webURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            web_url = get_web_url()
+        except KeyError:
+            if strict:
+                raise
+            web_url = cast(Union[Unset, str], UNSET)
 
         request = cls(
             api_url=api_url,
