@@ -44,27 +44,36 @@ class RequestTaskBaseFields:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_fields() -> Union[Unset, Fields]:
-            fields: Union[Unset, Fields] = UNSET
+            fields: Union[Unset, Union[Unset, Fields]] = UNSET
             _fields = d.pop("fields")
+
             if not isinstance(_fields, Unset):
                 fields = Fields.from_dict(_fields)
 
             return fields
 
-        fields = get_fields() if "fields" in d else cast(Union[Unset, Fields], UNSET)
+        try:
+            fields = get_fields()
+        except KeyError:
+            if strict:
+                raise
+            fields = cast(Union[Unset, Fields], UNSET)
 
         def get_sample_group_ids() -> Union[Unset, List[str]]:
             sample_group_ids = cast(List[str], d.pop("sampleGroupIds"))
 
             return sample_group_ids
 
-        sample_group_ids = (
-            get_sample_group_ids() if "sampleGroupIds" in d else cast(Union[Unset, List[str]], UNSET)
-        )
+        try:
+            sample_group_ids = get_sample_group_ids()
+        except KeyError:
+            if strict:
+                raise
+            sample_group_ids = cast(Union[Unset, List[str]], UNSET)
 
         request_task_base_fields = cls(
             fields=fields,
