@@ -40,20 +40,25 @@ class RequestTasksBulkCreateResponse:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_tasks() -> Union[Unset, List[RequestTask]]:
             tasks = []
             _tasks = d.pop("tasks")
             for tasks_item_data in _tasks or []:
-                tasks_item = RequestTask.from_dict(tasks_item_data)
+                tasks_item = RequestTask.from_dict(tasks_item_data, strict=False)
 
                 tasks.append(tasks_item)
 
             return tasks
 
-        tasks = get_tasks() if "tasks" in d else cast(Union[Unset, List[RequestTask]], UNSET)
+        try:
+            tasks = get_tasks()
+        except KeyError:
+            if strict:
+                raise
+            tasks = cast(Union[Unset, List[RequestTask]], UNSET)
 
         request_tasks_bulk_create_response = cls(
             tasks=tasks,
