@@ -40,20 +40,25 @@ class RequestsBulkGet:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_requests() -> Union[Unset, List[Request]]:
             requests = []
             _requests = d.pop("requests")
             for requests_item_data in _requests or []:
-                requests_item = Request.from_dict(requests_item_data)
+                requests_item = Request.from_dict(requests_item_data, strict=False)
 
                 requests.append(requests_item)
 
             return requests
 
-        requests = get_requests() if "requests" in d else cast(Union[Unset, List[Request]], UNSET)
+        try:
+            requests = get_requests()
+        except KeyError:
+            if strict:
+                raise
+            requests = cast(Union[Unset, List[Request]], UNSET)
 
         requests_bulk_get = cls(
             requests=requests,
