@@ -45,7 +45,7 @@ class TokenCreate:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_grant_type() -> TokenCreateGrantType:
@@ -57,19 +57,34 @@ class TokenCreate:
 
             return grant_type
 
-        grant_type = get_grant_type() if "grant_type" in d else cast(TokenCreateGrantType, UNSET)
+        try:
+            grant_type = get_grant_type()
+        except KeyError:
+            if strict:
+                raise
+            grant_type = cast(TokenCreateGrantType, UNSET)
 
         def get_client_id() -> Union[Unset, str]:
             client_id = d.pop("client_id")
             return client_id
 
-        client_id = get_client_id() if "client_id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            client_id = get_client_id()
+        except KeyError:
+            if strict:
+                raise
+            client_id = cast(Union[Unset, str], UNSET)
 
         def get_client_secret() -> Union[Unset, str]:
             client_secret = d.pop("client_secret")
             return client_secret
 
-        client_secret = get_client_secret() if "client_secret" in d else cast(Union[Unset, str], UNSET)
+        try:
+            client_secret = get_client_secret()
+        except KeyError:
+            if strict:
+                raise
+            client_secret = cast(Union[Unset, str], UNSET)
 
         token_create = cls(
             grant_type=grant_type,
