@@ -140,7 +140,7 @@ class WorkflowTaskGroup:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_execution_type() -> Union[Unset, WorkflowTaskGroupExecutionType]:
@@ -154,133 +154,187 @@ class WorkflowTaskGroup:
 
             return execution_type
 
-        execution_type = (
-            get_execution_type()
-            if "executionType" in d
-            else cast(Union[Unset, WorkflowTaskGroupExecutionType], UNSET)
-        )
+        try:
+            execution_type = get_execution_type()
+        except KeyError:
+            if strict:
+                raise
+            execution_type = cast(Union[Unset, WorkflowTaskGroupExecutionType], UNSET)
 
         def get_creation_origin() -> Union[Unset, CreationOrigin]:
-            creation_origin: Union[Unset, CreationOrigin] = UNSET
+            creation_origin: Union[Unset, Union[Unset, CreationOrigin]] = UNSET
             _creation_origin = d.pop("creationOrigin")
+
             if not isinstance(_creation_origin, Unset):
                 creation_origin = CreationOrigin.from_dict(_creation_origin)
 
             return creation_origin
 
-        creation_origin = (
-            get_creation_origin() if "creationOrigin" in d else cast(Union[Unset, CreationOrigin], UNSET)
-        )
+        try:
+            creation_origin = get_creation_origin()
+        except KeyError:
+            if strict:
+                raise
+            creation_origin = cast(Union[Unset, CreationOrigin], UNSET)
 
         def get_creator() -> Union[Unset, UserSummary]:
-            creator: Union[Unset, UserSummary] = UNSET
+            creator: Union[Unset, Union[Unset, UserSummary]] = UNSET
             _creator = d.pop("creator")
+
             if not isinstance(_creator, Unset):
                 creator = UserSummary.from_dict(_creator)
 
             return creator
 
-        creator = get_creator() if "creator" in d else cast(Union[Unset, UserSummary], UNSET)
+        try:
+            creator = get_creator()
+        except KeyError:
+            if strict:
+                raise
+            creator = cast(Union[Unset, UserSummary], UNSET)
 
         def get_folder() -> Union[Unset, Folder]:
-            folder: Union[Unset, Folder] = UNSET
+            folder: Union[Unset, Union[Unset, Folder]] = UNSET
             _folder = d.pop("folder")
+
             if not isinstance(_folder, Unset):
                 folder = Folder.from_dict(_folder)
 
             return folder
 
-        folder = get_folder() if "folder" in d else cast(Union[Unset, Folder], UNSET)
+        try:
+            folder = get_folder()
+        except KeyError:
+            if strict:
+                raise
+            folder = cast(Union[Unset, Folder], UNSET)
 
         def get_outputs() -> Union[Unset, List[WorkflowOutputSummary]]:
             outputs = []
             _outputs = d.pop("outputs")
             for outputs_item_data in _outputs or []:
-                outputs_item = WorkflowOutputSummary.from_dict(outputs_item_data)
+                outputs_item = WorkflowOutputSummary.from_dict(outputs_item_data, strict=False)
 
                 outputs.append(outputs_item)
 
             return outputs
 
-        outputs = get_outputs() if "outputs" in d else cast(Union[Unset, List[WorkflowOutputSummary]], UNSET)
+        try:
+            outputs = get_outputs()
+        except KeyError:
+            if strict:
+                raise
+            outputs = cast(Union[Unset, List[WorkflowOutputSummary]], UNSET)
 
         def get_responsible_team() -> Union[Unset, None, TeamSummary]:
             responsible_team = None
             _responsible_team = d.pop("responsibleTeam")
+
             if _responsible_team is not None and not isinstance(_responsible_team, Unset):
                 responsible_team = TeamSummary.from_dict(_responsible_team)
 
             return responsible_team
 
-        responsible_team = (
-            get_responsible_team() if "responsibleTeam" in d else cast(Union[Unset, None, TeamSummary], UNSET)
-        )
+        try:
+            responsible_team = get_responsible_team()
+        except KeyError:
+            if strict:
+                raise
+            responsible_team = cast(Union[Unset, None, TeamSummary], UNSET)
 
         def get_watchers() -> Union[Unset, List[UserSummary]]:
             watchers = []
             _watchers = d.pop("watchers")
             for watchers_item_data in _watchers or []:
-                watchers_item = UserSummary.from_dict(watchers_item_data)
+                watchers_item = UserSummary.from_dict(watchers_item_data, strict=False)
 
                 watchers.append(watchers_item)
 
             return watchers
 
-        watchers = get_watchers() if "watchers" in d else cast(Union[Unset, List[UserSummary]], UNSET)
+        try:
+            watchers = get_watchers()
+        except KeyError:
+            if strict:
+                raise
+            watchers = cast(Union[Unset, List[UserSummary]], UNSET)
 
         def get_web_url() -> Union[Unset, str]:
             web_url = d.pop("webURL")
             return web_url
 
-        web_url = get_web_url() if "webURL" in d else cast(Union[Unset, str], UNSET)
+        try:
+            web_url = get_web_url()
+        except KeyError:
+            if strict:
+                raise
+            web_url = cast(Union[Unset, str], UNSET)
 
         def get_workflow_task_schema() -> Union[Unset, WorkflowTaskSchemaSummary]:
-            workflow_task_schema: Union[Unset, WorkflowTaskSchemaSummary] = UNSET
+            workflow_task_schema: Union[Unset, Union[Unset, WorkflowTaskSchemaSummary]] = UNSET
             _workflow_task_schema = d.pop("workflowTaskSchema")
+
             if not isinstance(_workflow_task_schema, Unset):
                 workflow_task_schema = WorkflowTaskSchemaSummary.from_dict(_workflow_task_schema)
 
             return workflow_task_schema
 
-        workflow_task_schema = (
-            get_workflow_task_schema()
-            if "workflowTaskSchema" in d
-            else cast(Union[Unset, WorkflowTaskSchemaSummary], UNSET)
-        )
+        try:
+            workflow_task_schema = get_workflow_task_schema()
+        except KeyError:
+            if strict:
+                raise
+            workflow_task_schema = cast(Union[Unset, WorkflowTaskSchemaSummary], UNSET)
 
         def get_workflow_tasks() -> Union[Unset, List[WorkflowTaskSummary]]:
             workflow_tasks = []
             _workflow_tasks = d.pop("workflowTasks")
             for workflow_tasks_item_data in _workflow_tasks or []:
-                workflow_tasks_item = WorkflowTaskSummary.from_dict(workflow_tasks_item_data)
+                workflow_tasks_item = WorkflowTaskSummary.from_dict(workflow_tasks_item_data, strict=False)
 
                 workflow_tasks.append(workflow_tasks_item)
 
             return workflow_tasks
 
-        workflow_tasks = (
-            get_workflow_tasks()
-            if "workflowTasks" in d
-            else cast(Union[Unset, List[WorkflowTaskSummary]], UNSET)
-        )
+        try:
+            workflow_tasks = get_workflow_tasks()
+        except KeyError:
+            if strict:
+                raise
+            workflow_tasks = cast(Union[Unset, List[WorkflowTaskSummary]], UNSET)
 
         def get_display_id() -> Union[Unset, str]:
             display_id = d.pop("displayId")
             return display_id
 
-        display_id = get_display_id() if "displayId" in d else cast(Union[Unset, str], UNSET)
+        try:
+            display_id = get_display_id()
+        except KeyError:
+            if strict:
+                raise
+            display_id = cast(Union[Unset, str], UNSET)
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         workflow_task_group = cls(
             execution_type=execution_type,
