@@ -45,30 +45,38 @@ class WorkflowTaskGroupsPaginatedList:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_next_token() -> Union[Unset, str]:
             next_token = d.pop("nextToken")
             return next_token
 
-        next_token = get_next_token() if "nextToken" in d else cast(Union[Unset, str], UNSET)
+        try:
+            next_token = get_next_token()
+        except KeyError:
+            if strict:
+                raise
+            next_token = cast(Union[Unset, str], UNSET)
 
         def get_workflow_task_groups() -> Union[Unset, List[WorkflowTaskGroup]]:
             workflow_task_groups = []
             _workflow_task_groups = d.pop("workflowTaskGroups")
             for workflow_task_groups_item_data in _workflow_task_groups or []:
-                workflow_task_groups_item = WorkflowTaskGroup.from_dict(workflow_task_groups_item_data)
+                workflow_task_groups_item = WorkflowTaskGroup.from_dict(
+                    workflow_task_groups_item_data, strict=False
+                )
 
                 workflow_task_groups.append(workflow_task_groups_item)
 
             return workflow_task_groups
 
-        workflow_task_groups = (
-            get_workflow_task_groups()
-            if "workflowTaskGroups" in d
-            else cast(Union[Unset, List[WorkflowTaskGroup]], UNSET)
-        )
+        try:
+            workflow_task_groups = get_workflow_task_groups()
+        except KeyError:
+            if strict:
+                raise
+            workflow_task_groups = cast(Union[Unset, List[WorkflowTaskGroup]], UNSET)
 
         workflow_task_groups_paginated_list = cls(
             next_token=next_token,
