@@ -170,7 +170,7 @@ class WorkflowTaskSchema:
         return field_dict
 
     @classmethod
-    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any], strict: bool = False) -> T:
         d = src_dict.copy()
 
         def get_execution_type() -> Union[Unset, WorkflowTaskSchemaExecutionType]:
@@ -184,117 +184,142 @@ class WorkflowTaskSchema:
 
             return execution_type
 
-        execution_type = (
-            get_execution_type()
-            if "executionType" in d
-            else cast(Union[Unset, WorkflowTaskSchemaExecutionType], UNSET)
-        )
+        try:
+            execution_type = get_execution_type()
+        except KeyError:
+            if strict:
+                raise
+            execution_type = cast(Union[Unset, WorkflowTaskSchemaExecutionType], UNSET)
 
         def get_can_set_assignee_on_task_creation() -> Union[Unset, bool]:
             can_set_assignee_on_task_creation = d.pop("canSetAssigneeOnTaskCreation")
             return can_set_assignee_on_task_creation
 
-        can_set_assignee_on_task_creation = (
-            get_can_set_assignee_on_task_creation()
-            if "canSetAssigneeOnTaskCreation" in d
-            else cast(Union[Unset, bool], UNSET)
-        )
+        try:
+            can_set_assignee_on_task_creation = get_can_set_assignee_on_task_creation()
+        except KeyError:
+            if strict:
+                raise
+            can_set_assignee_on_task_creation = cast(Union[Unset, bool], UNSET)
 
         def get_default_creation_folder_id() -> Union[Unset, None, str]:
             default_creation_folder_id = d.pop("defaultCreationFolderId")
             return default_creation_folder_id
 
-        default_creation_folder_id = (
-            get_default_creation_folder_id()
-            if "defaultCreationFolderId" in d
-            else cast(Union[Unset, None, str], UNSET)
-        )
+        try:
+            default_creation_folder_id = get_default_creation_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            default_creation_folder_id = cast(Union[Unset, None, str], UNSET)
 
         def get_default_entry_execution_folder_id() -> Union[Unset, None, str]:
             default_entry_execution_folder_id = d.pop("defaultEntryExecutionFolderId")
             return default_entry_execution_folder_id
 
-        default_entry_execution_folder_id = (
-            get_default_entry_execution_folder_id()
-            if "defaultEntryExecutionFolderId" in d
-            else cast(Union[Unset, None, str], UNSET)
-        )
+        try:
+            default_entry_execution_folder_id = get_default_entry_execution_folder_id()
+        except KeyError:
+            if strict:
+                raise
+            default_entry_execution_folder_id = cast(Union[Unset, None, str], UNSET)
 
         def get_default_responsible_team() -> Union[Unset, None, TeamSummary]:
             default_responsible_team = None
             _default_responsible_team = d.pop("defaultResponsibleTeam")
+
             if _default_responsible_team is not None and not isinstance(_default_responsible_team, Unset):
                 default_responsible_team = TeamSummary.from_dict(_default_responsible_team)
 
             return default_responsible_team
 
-        default_responsible_team = (
-            get_default_responsible_team()
-            if "defaultResponsibleTeam" in d
-            else cast(Union[Unset, None, TeamSummary], UNSET)
-        )
+        try:
+            default_responsible_team = get_default_responsible_team()
+        except KeyError:
+            if strict:
+                raise
+            default_responsible_team = cast(Union[Unset, None, TeamSummary], UNSET)
 
         def get_entry_template_id() -> Union[Unset, None, str]:
             entry_template_id = d.pop("entryTemplateId")
             return entry_template_id
 
-        entry_template_id = (
-            get_entry_template_id() if "entryTemplateId" in d else cast(Union[Unset, None, str], UNSET)
-        )
+        try:
+            entry_template_id = get_entry_template_id()
+        except KeyError:
+            if strict:
+                raise
+            entry_template_id = cast(Union[Unset, None, str], UNSET)
 
         def get_prefix() -> Union[Unset, str]:
             prefix = d.pop("prefix")
             return prefix
 
-        prefix = get_prefix() if "prefix" in d else cast(Union[Unset, str], UNSET)
+        try:
+            prefix = get_prefix()
+        except KeyError:
+            if strict:
+                raise
+            prefix = cast(Union[Unset, str], UNSET)
 
         def get_status_lifecycle() -> Union[Unset, WorkflowTaskStatusLifecycle]:
-            status_lifecycle: Union[Unset, WorkflowTaskStatusLifecycle] = UNSET
+            status_lifecycle: Union[Unset, Union[Unset, WorkflowTaskStatusLifecycle]] = UNSET
             _status_lifecycle = d.pop("statusLifecycle")
+
             if not isinstance(_status_lifecycle, Unset):
                 status_lifecycle = WorkflowTaskStatusLifecycle.from_dict(_status_lifecycle)
 
             return status_lifecycle
 
-        status_lifecycle = (
-            get_status_lifecycle()
-            if "statusLifecycle" in d
-            else cast(Union[Unset, WorkflowTaskStatusLifecycle], UNSET)
-        )
+        try:
+            status_lifecycle = get_status_lifecycle()
+        except KeyError:
+            if strict:
+                raise
+            status_lifecycle = cast(Union[Unset, WorkflowTaskStatusLifecycle], UNSET)
 
         def get_task_group_prefix() -> Union[Unset, str]:
             task_group_prefix = d.pop("taskGroupPrefix")
             return task_group_prefix
 
-        task_group_prefix = (
-            get_task_group_prefix() if "taskGroupPrefix" in d else cast(Union[Unset, str], UNSET)
-        )
+        try:
+            task_group_prefix = get_task_group_prefix()
+        except KeyError:
+            if strict:
+                raise
+            task_group_prefix = cast(Union[Unset, str], UNSET)
 
         def get_workflow_output_schema() -> Union[Unset, None, WorkflowOutputSchema]:
             workflow_output_schema = None
             _workflow_output_schema = d.pop("workflowOutputSchema")
+
             if _workflow_output_schema is not None and not isinstance(_workflow_output_schema, Unset):
                 workflow_output_schema = WorkflowOutputSchema.from_dict(_workflow_output_schema)
 
             return workflow_output_schema
 
-        workflow_output_schema = (
-            get_workflow_output_schema()
-            if "workflowOutputSchema" in d
-            else cast(Union[Unset, None, WorkflowOutputSchema], UNSET)
-        )
+        try:
+            workflow_output_schema = get_workflow_output_schema()
+        except KeyError:
+            if strict:
+                raise
+            workflow_output_schema = cast(Union[Unset, None, WorkflowOutputSchema], UNSET)
 
         def get_archive_record() -> Union[Unset, None, ArchiveRecord]:
             archive_record = None
             _archive_record = d.pop("archiveRecord")
+
             if _archive_record is not None and not isinstance(_archive_record, Unset):
                 archive_record = ArchiveRecord.from_dict(_archive_record)
 
             return archive_record
 
-        archive_record = (
-            get_archive_record() if "archiveRecord" in d else cast(Union[Unset, None, ArchiveRecord], UNSET)
-        )
+        try:
+            archive_record = get_archive_record()
+        except KeyError:
+            if strict:
+                raise
+            archive_record = cast(Union[Unset, None, ArchiveRecord], UNSET)
 
         def get_field_definitions() -> Union[
             Unset,
@@ -334,7 +359,7 @@ class WorkflowTaskSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SimpleFieldDefinition.from_dict(data)
+                        field_definitions_item = SimpleFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -342,7 +367,7 @@ class WorkflowTaskSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = IntegerFieldDefinition.from_dict(data)
+                        field_definitions_item = IntegerFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -350,7 +375,7 @@ class WorkflowTaskSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = FloatFieldDefinition.from_dict(data)
+                        field_definitions_item = FloatFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -358,7 +383,7 @@ class WorkflowTaskSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = DropdownFieldDefinition.from_dict(data)
+                        field_definitions_item = DropdownFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -366,7 +391,7 @@ class WorkflowTaskSchema:
                     try:
                         if not isinstance(data, dict):
                             raise TypeError()
-                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data)
+                        field_definitions_item = SchemaLinkFieldDefinition.from_dict(data, strict=True)
 
                         return field_definitions_item
                     except:  # noqa: E722
@@ -379,10 +404,12 @@ class WorkflowTaskSchema:
 
             return field_definitions
 
-        field_definitions = (
-            get_field_definitions()
-            if "fieldDefinitions" in d
-            else cast(
+        try:
+            field_definitions = get_field_definitions()
+        except KeyError:
+            if strict:
+                raise
+            field_definitions = cast(
                 Union[
                     Unset,
                     List[
@@ -398,25 +425,39 @@ class WorkflowTaskSchema:
                 ],
                 UNSET,
             )
-        )
 
         def get_id() -> Union[Unset, str]:
             id = d.pop("id")
             return id
 
-        id = get_id() if "id" in d else cast(Union[Unset, str], UNSET)
+        try:
+            id = get_id()
+        except KeyError:
+            if strict:
+                raise
+            id = cast(Union[Unset, str], UNSET)
 
         def get_name() -> Union[Unset, str]:
             name = d.pop("name")
             return name
 
-        name = get_name() if "name" in d else cast(Union[Unset, str], UNSET)
+        try:
+            name = get_name()
+        except KeyError:
+            if strict:
+                raise
+            name = cast(Union[Unset, str], UNSET)
 
         def get_type() -> Union[Unset, str]:
             type = d.pop("type")
             return type
 
-        type = get_type() if "type" in d else cast(Union[Unset, str], UNSET)
+        try:
+            type = get_type()
+        except KeyError:
+            if strict:
+                raise
+            type = cast(Union[Unset, str], UNSET)
 
         workflow_task_schema = cls(
             execution_type=execution_type,
